#!/bin/bash

#  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
#
#  This file is part of Lightweight Bartering Grid.
#  Lightweight Bartering Grid is free software;
#  you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Lightweight Bartering Grid is distributed in the hope that it will be
#  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Lightweight Bartering Grid; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Authors:      Xavier Dalem, Cyril Briquet
# Last revised: January 9th, 2008

BASE_TITLE='LBG Resource deployer'

if ! ([ -n "`which zenity`" ] && [ -x `which zenity` ]); then
	echo "Zenity is not available"
	exit
fi

###

if ! zenity --question --title="$BASE_TITLE" --text="A Resource is going to be deployed on this computer.\nYou may cancel deployment at any point.\n\nProceed to specify the directory where *.jar files (lightweight_bartering_grid.jar and required libraries) are located."; then
	exit
fi

# Fix PWD
cd `dirname $0`

JAR_DIR=`zenity --file-selection --title="$BASE_TITLE - Select .jar files directory" --directory --directory --filename="$PWD/../../"`

if [ -z "$JAR_DIR" ]; then
	zenity --error --title="$BASE_TITLE - Invalid directory" --text="The given directory is not valid."
	exit
fi

LBG_CLASSPATH=''
for jar in `/bin/ls -1 $JAR_DIR/*.jar`; do
	LBG_CLASSPATH="$jar:$LBG_CLASSPATH"
done

###

zenity --info --title="$BASE_TITLE - Configuration" --text="Select a configuration file for the Resource."

PEER_CONFIG=`zenity --file-selection --title="$BASE_TITLE - Configuration" --filename="$PWD/../local/config/"`

if [ -z "$PEER_CONFIG" ] ; then
	zenity --error --title="$BASE_TITLE - Invalid configuration" --text="The given configuration file is not valid."
	exit
fi

###

java -cp "$LBG_CLASSPATH" lbg.middleware.LaunchResource -q -c "$PEER_CONFIG" &

zenity --info --title="$BASE_TITLE - Resource started" --text="The Resource is up and running.\nYou may safely close this window"

