#!/bin/bash

#  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
#
#  This file is part of Lightweight Bartering Grid.
#  Lightweight Bartering Grid is free software;
#  you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Lightweight Bartering Grid is distributed in the hope that it will be
#  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Lightweight Bartering Grid; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Authors:      Cyril Briquet, Xavier Dalem
# Last revised: March 25th, 2008

# ----------------------------------------------------------------

# paths
SSH_BIN="ssh -o ConnectTimeOut=2 -o ForwardX11=no"
SCP_BIN="scp -q -o ConnectTimeOut=2"
SHELL_BIN="/bin/bash"
JAVA_BIN="java -Xmx512M"
SRC_JAR_DIR="../../jars"
if [ -z "$SRC_CONFIG_DIR" ]; then # Allow overriding config dir
	SRC_CONFIG_DIR="config"
fi
if [ -z "$LBG_DEPL_DIR" ]; then # Allow overriding dependencies dir
	LBG_DEPL_DIR=".lbg"
fi
PEER_PROPS_FILENAME="${SRC_CONFIG_DIR}/peerconfig.properties"
RES_PROPS_FILENAME="${SRC_CONFIG_DIR}/resourceconfig.properties"
if [ -r "$PEER_PROPS_FILENAME" -a -r "$RES_PROPS_FILENAME" ]; then
	PEER_CACHE_DIR=`grep -i CACHE_DIR ${PEER_PROPS_FILENAME} | cut -f 2 -d"="`
	RES_CACHE_DIR=`grep -i CACHE_DIR ${RES_PROPS_FILENAME} | cut -f 2 -d"="`
	RES_STATS_DIR=`grep -i STATS_DIR ${RES_PROPS_FILENAME} | cut -f 2 -d"="`
fi

LBG_LIBS="$LBG_DEPL_DIR/lightweight_bartering_grid.jar:$LBG_DEPL_DIR/Azureus2.5.0.4.jar:$LBG_DEPL_DIR/commons-logging-1.1.jar:$LBG_DEPL_DIR/commons-math-1.1.jar:$LBG_DEPL_DIR/edtftpj.jar:$LBG_DEPL_DIR/ftpserver-dev.jar:${LBG_DEPL_DIR}/jfreechart-1.0.9.jar:${LBG_DEPL_DIR}/jcommon-1.0.12.jar:${LBG_DEPL_DIR}/iText-2.0.8.jar"

#SE_MONITORING_FLAG="-agentlib:yjpagent"
#PEER_MONITORING_FLAG="-agentlib:yjpagent"
#RES_MONITORING_FLAG="-agentlib:yjpagent"

SE_PORT=50111
QUIET="-q" # Set to "" for verbose output

# By default, will assume the dependencies directory is *not* NFS-shared.
# If previously set to false, will deploy jars to each Peer and each Resource.
test -z "$CLUSTER_DEPLOYMENT" && CLUSTER_DEPLOYMENT=true

# global accumulators
PEER_LIST=
GLOBAL_RES_COUNT=0

# color codes
if [ -n "$TERM" ] && [ "$TERM" != "dumb" ]; then
        WIN="[\e[34mOK\e[0m]"
        FAIL="[\e[31mXX\e[0m]"
else
        WIN="[OK]"
        FAIL="[XX]"
fi

# ----------------------------------------------------------------

function greetings() {
	echo -e "\nLightweight Bartering Grid $1 script"
	echo    "  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem"
	echo -e "  Contact: C.Briquet@ulg.ac.be\n"
	echo    "Grid"
}

function tacticalPause() {
	sleep 0.6
}

# parameters: user@machine, returns: machine
EXTRACT_PEER_HOSTNAME_RETVAL=
function extractHostname() {
	EXTRACT_PEER_HOSTNAME_RETVAL=`echo -e $1 | cut -f2 -d@`
}

# parameters: user@machine
function terminateJavaVM() {
 ${SSH_BIN} $1 \
   "${SHELL_BIN} -c \" killall -q java 2> /dev/null\" "
 if test $? -eq 0 ; then
     extractHostname $1
     echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${WIN}  terminated all Java VM"
  else
     extractHostname $1
     echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL}  no Java VM terminated"
  fi
}

# parameters: user@machine
# Uploads required files (jars and config) in LBG_DEPL_DIR
function uploadDeps() {
	echo -e "|"
	${SCP_BIN} ${SRC_JAR_DIR}/* $1:${LBG_DEPL_DIR}
	if [ -n "$PEER_CACHE_DIR" ]; then
		${SSH_BIN} $1 \
			"${SHELL_BIN} -c \" chmod 700 ${PEER_CACHE_DIR} ${RES_CACHE_DIR} ${RES_STATS_DIR} 2> /dev/null\" "
	fi
	${SCP_BIN} ${SRC_CONFIG_DIR}/*.properties $1:${LBG_DEPL_DIR}

	if test $? -eq 0 ; then
		extractHostname $1
		echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${WIN} uploaded files to ${LBG_DEPL_DIR}"
	else
		extractHostname $1
		echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not upload files to ${LBG_DEPL_DIR}"
	fi
}

# parameters: user@machine
# ${LBG_DEPL_DIR} is supposed to contain all required files
function deploySearchEngine() {
	echo -e "|"
	terminateJavaVM $1
	$SSH_BIN $1 "rm -rf '${LBG_DEPL_DIR}' ; mkdir -p '${LBG_DEPL_DIR}/logs' '${LBG_DEPL_DIR}/stats' ; chmod -R go-rwx '${LBG_DEPL_DIR}'"
	uploadDeps $1
	${SSH_BIN} $1 \
		"${SHELL_BIN} -c \"${JAVA_BIN} ${SE_MONITORING_FLAG} -cp '${LBG_LIBS}' -ea lbg.middleware.LaunchSearchEngine -p $SE_PORT $QUIET > '$LBG_DEPL_DIR/logs/searchengine' 2>&1 &\" " &

	RETVAL=$?
	tacticalPause
	extractHostname $1

	if test $RETVAL -ne 0 ; then # SSH failure
		echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not deploy a Search Engine"
	elif $SSH_BIN $1 "ps -o cmd -C '$JAVA_BIN'" | tail -n +2 | grep LaunchSearchEngine  > /dev/null 2>&1 ; then
		echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${WIN} deployed a Search Engine"
	else
		echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not deploy a Search Engine"
	fi
}

# parameters: user@machine search_engine_machine
# ${LBG_DEPL_DIR} is supposed to contain all required files
function deployPeer() {
	extractHostname $1
	${SSH_BIN} $1 \
		"${SHELL_BIN} -c \"${JAVA_BIN} ${PEER_MONITORING_FLAG} -cp '${LBG_LIBS}' -ea lbg.middleware.LaunchPeer -c '${LBG_DEPL_DIR}/peerconfig.properties' -s '$2' $QUIET > '$LBG_DEPL_DIR/logs/$EXTRACT_PEER_HOSTNAME_RETVAL' 2>&1 &\" "

	RETVAL=$?
	tacticalPause
	if test $RETVAL -ne 0 ; then # Fail, return already
		return $RETVAL
	fi

	$SSH_BIN $1 "ps -o cmd -C '$JAVA_BIN'" | tail -n +2 | grep LaunchPeer > /dev/null 2>&1

	return $?
}

# parameters: user@machine peer_machine
# ${LBG_DEPL_DIR} is supposed to contain all required files
# If global variable CLUSTER_DEPLOYMENT is evaluated to false,
# jars are sent to the Resource
function deployResource() {
	if [ "$CLUSTER_DEPLOYMENT" = "false" ] ; then
		uploadDeps $1
	fi

	extractHostname $1

	${SSH_BIN} $1 \
		"${SHELL_BIN} -c \"${JAVA_BIN} ${RES_MONITORING_FLAG} -cp '${LBG_LIBS}' -ea lbg.middleware.LaunchResource -c '${LBG_DEPL_DIR}/resourceconfig.properties' --peerhost '$2' $QUIET > '$LBG_DEPL_DIR/logs/$EXTRACT_PEER_HOSTNAME_RETVAL' 2>&1 &\" "

	RETVAL=$?
	tacticalPause
	if test $RETVAL -ne 0 ; then # Fail, return already
		return $RETVAL
	fi

	$SSH_BIN $1 "ps -o cmd -C '$JAVA_BIN'" | tail -n +2 | grep LaunchResource > /dev/null 2>&1

	return $?
}

# parameters: "user@machine user@machine user@machine ... user@machine" user@search_engine_machine
# ${LBG_DEPL_DIR} is going to be filled with all required files
function deploySite() {
	echo -e "|"
	extractHostname $2
	SEARCH_ENGINE_HOSTNAME=${EXTRACT_PEER_HOSTNAME_RETVAL}

	# Step 1 - terminate running Grid nodes and prepare deploy/logs directories
	for target in $1 ; do
		terminateJavaVM $target
		$SSH_BIN $target "rm -rf '${LBG_DEPL_DIR}' ; mkdir -p '${LBG_DEPL_DIR}/logs' '${LBG_DEPL_DIR}/stats' ; chmod -R go-rwx '${LBG_DEPL_DIR}'"
	done

	# Step 2 - iterate over machines
	# start in Peer mode
	PEER_MACHINE=
	SITE_RES_COUNT=0
	for target in $1 ; do
		# branch to Peer mode or Resource mode
		if [ -z ${PEER_MACHINE} ] ; then
			# upload required files
			uploadDeps ${target}
			if test $? -eq 0 ; then
				# actually deploy a Peer
				deployPeer ${target} ${SEARCH_ENGINE_HOSTNAME}
				if test $? -eq 0 ; then
					# switch to Resource mode
					extractHostname ${target}
					PEER_MACHINE=${EXTRACT_PEER_HOSTNAME_RETVAL}
					# accumulate Peer hostname
					PEER_LIST="${PEER_LIST} ${PEER_MACHINE}"
					# report success
					echo -e "|-- ${PEER_MACHINE}  ${WIN} deployed a Peer"
				else
					extractHostname ${target}
					echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not deploy a Peer"
				fi
			else
				extractHostname ${target}
				echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not deploy a Peer"
			fi
		else
			# actually deploy a Resource
			deployResource ${target} ${PEER_MACHINE}
			if test $? -eq 0 ; then
				extractHostname ${target}
				echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${WIN} deployed a Resource"
				SITE_RES_COUNT=$((SITE_RES_COUNT+1))
				GLOBAL_RES_COUNT=$((GLOBAL_RES_COUNT+1))
			else
				extractHostname ${target}
				echo -e "|-- ${EXTRACT_PEER_HOSTNAME_RETVAL}  ${FAIL} could not deploy a Resource"
			fi
		fi
	done
	echo "|-- Deployed ${SITE_RES_COUNT} Resources"
}

# parameters: "user@machine user@machine user@machine ... user@machine"
function shutdownSite() {
  echo -e "|"
  for target in $1 ; do
    terminateJavaVM ${target}
  done
}

# ----------------------------------------------------------------
