/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Tank.java

package lbg.common;

import lbg.common.math.*;

/** A Tank provides shared storage for frequently used object numbers
 * (e.g. Integer, Long, ...).
 * @author Cyril Briquet
 */
public abstract class Tank {

	public static Integer newInteger(int i) {
		
		if ((i >= 0) && (i < Tank.I_STORAGE_SIZE)) {
			Tank.i_storage_active++;
			return Tank.i_storage[i];
		}
		else {
			Tank.i_storage_passive++;
			return Integer.valueOf(i);
		}
		
	}

/* unused code --
	public synchronized static double[] newAttributesArray() {
		
		if (Tank.da_storage_size > 0) {
			// Remove rightmost free double[]
			return Tank.da_storage[--Tank.da_storage_size];
		}
		else {
			for (int x = 0 ; x < Tank.DA_STORAGE_SIZE ; x++) {
				Tank.da_storage[x] =
					new double[InteractionAttributes.size()+1];
			}
			Tank.da_storage_size = Tank.DA_STORAGE_SIZE;
			
			return Tank.newAttributesArray();
		}
		
	}

	public synchronized static void releaseAttributesArray(double[] da) {

		if (Tank.da_storage_size < Tank.DA_STORAGE_SIZE) {
			Tank.da_storage[Tank.da_storage_size++] = da;
		}
		
	}
*/

	public static String toStaticString() {

		StringBuilder sb = new StringBuilder();
		
		sb.append("Tank Integer hit ratio=");
		sb.append(CommonMath.
					div_label(Tank.i_storage_active,
							  Tank.i_storage_active+Tank.i_storage_passive,
							  100));
		sb.append("%");
		sb.append(" (");
		sb.append(Tank.i_storage_active);
		sb.append(" hits)");

		return sb.toString();
		
	}

	static {
		
		Tank.i_storage = new Integer[Tank.I_STORAGE_SIZE];
		for (int x = 0 ; x < Tank.I_STORAGE_SIZE ; x++) {
			Tank.i_storage[x] = Integer.valueOf(x);
		}
		Tank.i_storage_active = 0;
		Tank.i_storage_passive = 0;
		
/* unused code --
		Tank.da_storage = new double[Tank.DA_STORAGE_SIZE][];
		for (int x = 0 ; x < Tank.DA_STORAGE_SIZE ; x++) {
			Tank.da_storage[x] =
				new double[InteractionAttributes.size()+1];
		}
		Tank.da_storage_size = Tank.DA_STORAGE_SIZE;
*/

	}
	
	private static final int I_STORAGE_SIZE = 4096;
	private static Integer[] i_storage;
	private static long i_storage_active;
	private static long i_storage_passive;

/* unused code --
	private static final int DA_STORAGE_SIZE = 10000;
	private static double[][] da_storage;
	private static int da_storage_size;
*/

}

