/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NullInputStream.java

package lbg.common.io;

import java.io.IOException;
import java.io.InputStream;

/** An InputStream that behaves as if it was empty.
 * 
 * Useful to set a dummy InputStream for a trustless application.
 * 
 * @author Xavier Dalem
 */
public class NullInputStream extends InputStream {
	
	public NullInputStream() {}

	public int available() {
		return 0;
	}
	
	/** @return -1 */
	public int read(byte[] b) throws IOException {
		return -1;
	}
	
	/** @return -1 */
	public int read(byte[] b, int off, int len) throws IOException {
		return -1;
	}
	
	/** @return -1 */
	public int read() throws IOException {
		return -1;
	}

}
