/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// MeasurementFactory.java

package lbg.common.math;

import lbg.common.exception.*;


/**
 * @author Cyril Briquet
 */
public abstract class MeasurementFactory {

	public String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[Measurement Factory]");
	
		return sb.toString();
		
	}
	
	// ****************************************************************

	/** Creates a new DescriptiveMeasurement.
	 * @param label measurement  label
	 * @exception GridException if a parameter is illegal
	 */
	public static Measurement createDescriptiveMeasurement(String label)
		throws GridException {
		
		return new DescriptiveMeasurement(label);
		
	}

	/** Creates a new DescriptiveMeasurement.
	 * @param label measurement  label
	 * @param ws window size
	 * @exception GridException if a parameter is illegal
	 */
	public static Measurement createDescriptiveMeasurement(String label,int ws)
		throws GridException {
		
		return new DescriptiveMeasurement(label,ws);
		
	}

	/** Creates a new SummarizedMeasurement.
	 * @param label measurement label
	 * @exception GridException if a parameter is illegal
	 */
	public static Measurement createSummarizedMeasurement(String label)
		throws GridException {
		
		return new SummarizedMeasurement(label);
		
	}

	// ****************************************************************

}

