/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// MeasurementSaver.java

package lbg.common.math;

import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonFileHandling.FILE_SEP;

/** A utility to save a {@link Measurement} into a file.
 * <p>Intended to be used as a shutdown hook (by Users, GridDataManagers, ...).
 * @see Runtime#addShutdownHook(Thread)
 * @author Xavier Dalem
 */
public class MeasurementSaver implements Runnable {

	private final Measurement measurement;
	private final String stat_directory;
	
	public MeasurementSaver(Measurement measurement, String stats_directory)
		throws GridException {

		if (measurement == null) {
			throw new GridException("Cannot track null measurement");
		}
		
		if (stats_directory == null) {
			throw new GridException("Invalid null directory");
		}

		this.measurement = measurement;
		this.stat_directory = stats_directory;

		CommonFileHandling.createDirectory(stats_directory);
	
	}

	public void run() {

		try {
			CommonFileHandling.
				writeFile(stat_directory+FILE_SEP+this.measurement.getLabel(),
						  this.measurement.toString());
		}
		catch (GridException e) {} // Not much we can do about it

	}

}

