/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// CommonNetHandling.java

package lbg.common.net;

import lbg.common.exception.*;
import static lbg.common.math.CommonMath.*;

import java.net.InetAddress;
import java.net.MalformedURLException;
import java.net.UnknownHostException;
import java.net.URL;

/** A CommonNetHandling provides common Net handling routines.
 * @author Cyril Briquet
 */
public abstract class CommonNetHandling {

	
	// ****************************************************************

	public static boolean isValidPort(int port) {
	
		return ((port > 0) && (port < 65536));
		
	}

	// ****************************************************************

	public static String getLocalHostName() throws GridException {
		
		InetAddress addr = null;
		
		try {
			addr = InetAddress.getLocalHost();
		}
		catch (UnknownHostException e) {
			throw new GridException(e);
		}
	
	     return addr.getHostName();

	}
	
	// ****************************************************************

	private static URL loadURL(String target_url) throws GridException {
		
		if (target_url == null) {
			throw new GridException("loadURL(): illegal target URL");
		}
		
		URL url = null;
		try {
			url = new URL(target_url);
		}
		catch (MalformedURLException e) {
			throw new GridException(e);
		}
		
		return url;
		
	}
	
	public static URL loadURLSafely(String target_url) {
		
		URL url = null;
		try {
			url = loadURL(target_url);
		}
		catch (GridException e) {
			url = null;
		}
		
		return url;
		
	}

	public static URL loadRandomURLSafely(String[] target_url) {
		
		URL url = null;
		try {
			int idx = sampleUniformDist(0,target_url.length-1);

			url = loadURL(target_url[idx]);
		}
		catch (GridException e) {
			url = null;
		}
		
		return url;
		
	}

	// ****************************************************************

	public static int getCoresCount() {
	
		return Runtime.getRuntime().availableProcessors();
		
	}

	// ****************************************************************

}
