/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Deque.java

package lbg.common.queueing.deque;

import lbg.common.exception.*;
import java.util.Iterator;

/** Double-ended queue that supports element insertion and removal at both ends.
 * <p>Original, unlicensed version written by Geoff Knagge (9806135),
 * last modified 14/8/1999.
 * <p>This version patched by Cyril Briquet, last modified 04/02/2007.
 * <p>Note: the sole purpose of this class is to provide
 * a J2SE 5.0 implementation of a Deque.
 * @author Cyril Briquet
 */
public interface Deque<T> {

	public int size();
	public boolean isEmpty();
	
	public void insertFirst(T O) throws GridException;
	public void insertLast(T O) throws GridException;
	
	public T removeFirst() throws GridException;
	public T removeLast() throws GridException;
	
	public T firstElement() throws GridException;
	public T lastElement() throws GridException;

	public Iterator<T> iterator();
	public Iterator<T> descendingIterator();

}

