/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// DoublyLinkedNode.java

package lbg.common.queueing.priority;

/** Helper class used to create double-linked lists.
 * @author Cyril Briquet
 */
public class DoublyLinkedNode<E> {
		
	public DoublyLinkedNode(E info,
							DoublyLinkedNode<E> prev,
							DoublyLinkedNode<E> next) {

		if (info == (E)null) {
			throw new NullPointerException("DoublyLinkedListNode(): "+
										   "null info");
		}

		/*
		if (prev == this) {
			throw new UnsupportedOperationException("DoublyLinked"+
													"ListNode(): "+
													"self-referencing "+
													"previous reference");
			}
			
		if (next == this) {
			throw new UnsupportedOperationException("DoublyLinked"+
													"ListNode(): "+
													"self-referencing "+
													"next reference");
		}
		*/
			
		if ((prev == next) && (prev != null)) {
			throw new UnsupportedOperationException("DoublyLinked"+
													"ListNode(): "+
													"circular "+
													"references");
		}
			
		this.info = info;
		this.prev = prev;
		this.next = next;
			
	}
		
	public DoublyLinkedNode(E info,
							DoublyLinkedNode<E> prev) {

		this(info,prev,null);

	}

	public DoublyLinkedNode(E info) {

		this(info,null,null);

	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[DoublyLinkedNode] info=");
		sb.append(this.info);
		sb.append(" prev=");
		if (this.prev != null) {
			sb.append(this.prev.info());
		}
		sb.append(" next=");
		if (this.next != null) {
			sb.append(this.next.info());
		}
		
		return sb.toString();
		
	}

	public synchronized E info() {
			
		return this.info;
			
	}
		
	public synchronized DoublyLinkedNode<E> getPrev() {
			
		return this.prev;
			
	}
		
	public synchronized DoublyLinkedNode<E> getNext() {
			
		return this.next;
			
	}

	public synchronized void setPrev(DoublyLinkedNode<E> prev) {

		if (prev == this) {
			throw new UnsupportedOperationException("setPrev(): "+
													"self-referencing "+
													"next reference");
		}
			
		if ((prev == this.next) &&
			(prev != null)) {
			throw new UnsupportedOperationException("setPrev(): "+
													"circular references");
		}

		this.prev = prev;
			
	}
		
	public synchronized void setNext(DoublyLinkedNode<E> next) {
			
		/* can happen !
		if (next == null) {
			throw new NullPointerException("setNext(): "+
										   "null previous reference");
		}
		*/

		if (next == this) {
			throw new UnsupportedOperationException("setNext(): "+
													"self-referencing "+
													"next reference");
		}
			
		if ((next == this.prev) &&
			(next != null)) {
			throw new UnsupportedOperationException("setNext(): "+
													"circular "+
													"references");
		}

		this.next = next;
		
	}
	
	private E info;
	private DoublyLinkedNode<E> prev;
	private DoublyLinkedNode<E> next;
	
}

