/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// GridHasher.java

package lbg.examples.hash;

import java.io.InputStream;
import java.security.MessageDigest;

import lbg.protocol.api.*;
import lbg.protocol.data.*;

/** Hash a set of data and return a user-readable hash.
 * @author Xavier Dalem */
public class GridHasher implements GridApplication {
	static private int BUFFER_SIZE=1024;
	private byte[] result = null;
	private GridData[] datas;
	private MessageDigest md = null;
	
	public GridHasher() {}
	
	public void setParameters(Object[] parameters) {
		if (parameters == null) {
			result = "null parameters\n".getBytes();
			return;
		}
		if (parameters.length != 1) {
			result = new String("Invalid number of parameters: "
				+ parameters.length + "\n").getBytes();
			return;
		}
		
		try {
			md = MessageDigest.getInstance((String)parameters[0]);
		} catch (java.security.NoSuchAlgorithmException e) {
			result = e.getMessage().getBytes();
		}
	}
	
	public void setInputData(GridData[] datas) {
		this.datas = datas;
	}
	
	public void setSupplier(String supplier_id) {}

	public void setPlaypen(String playpen_dir) {}

	public void compute() {
		if (result != null)
			return;
		if (md == null) {
			result = "null md\n".getBytes();
			return;
		}
		
		String output = "";
		
		for (GridData data: datas) {
			try {
				InputStream is = data.getInputStream();
				
				// Hash
				byte[] buffer = new byte[BUFFER_SIZE];
				int read = is.read(buffer, 0, BUFFER_SIZE);
				while (read != -1) {
					md.update(buffer, 0, read);
					read = is.read(buffer, 0, BUFFER_SIZE);
				}
				byte[] hash = md.digest();
				
				// Make a nice output
				output += lbg.protocol.data.GridDataManager.hashToString(hash)
					+ "\t" + data.id + "\n";
			} catch (Exception e) {
				result = (e.getMessage() + "\n").getBytes();
				return;
			}
		}
		
		result = output.getBytes();

		try { Thread.sleep(2000); } catch (InterruptedException e) {}
	}
	
	public byte[] getResult(){
		return result;
	}
}
