/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// HelloGrid.java

package lbg.examples.hello;

import java.io.InputStreamReader;

import lbg.protocol.api.*;
import lbg.protocol.data.*;

/** A 'Hello World' in 2 classes to test the grid.
 * Returned data is the sentence "Hello Grid", along with the input data, "a la"
 * ICMP Echo.
 * In case of error, the exception is returned
 * @author Xavier Dalem */
public class HelloGrid implements GridApplication {
	/* A hello world most likely uses small files */
	static private int BUFFER_SIZE=128;
	private byte[] result;
	private Hello hello;
	private GridData[] datas;
	
	public HelloGrid() {
		result = null;
	}
	
	public void setParameters(Object[] parameters) {}

	public void setSupplier(String supplier_id) {}
	
	public void setPlaypen(String playpen_dir) {}

	public void setInputData(GridData[] datas) {
		this.datas = datas;
	}
	
	public void compute() {
		hello = new Hello("Hello Grid");
		
		String output = "";
		
		for (GridData data: datas) {
			try {
				InputStreamReader isr =
					new InputStreamReader(data.getInputStream());
				
				char[] buffer = new char[BUFFER_SIZE];
				int read = isr.read(buffer, 0, BUFFER_SIZE);
				while (read != -1) {
					output += new String(buffer, 0, read);
					read = isr.read(buffer, 0, BUFFER_SIZE);
				}
				isr.close();
				output += "\n\n---\n\n";
			} catch (Exception e) {
				result = e.getMessage().getBytes();
				return;
			}
		}
		
		if (datas.length == 0)
			output = "[ No data to echo. Default message: shoop da woop ]\n";
		
		result = (hello.toString() + "\n" + output).getBytes();
		// TODO handle 0-seconds tasks
		try { Thread.sleep(2000); } catch (InterruptedException e) {}
	}
	
	public byte[] getResult(){
		return result;
	}

}

