/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LaunchSearchEngine.java

package lbg.middleware;

import lbg.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.common.net.*;
import lbg.searchengine.*;

/** Search engine server launcher
 * 
 * @author Xavier Dalem, Cyril Briquet
 * @since 2007-03-22
 */
public class LaunchSearchEngine {

	public static void main(String[] argv) throws GridException {

		final ArgsParser ap = new ArgsParser("lbg.LaunchResource");
		
		// Help
		ap.addHelper('?', "-help", "Show this help and exit");
		// Options
		//ap.addStringOption('i', "-id", true, null, "Engine ID");
		ap.addStringOption('i', "-id",false,
						   CommonNetHandling.getLocalHostName(),
						   "seach engine id");
		//ap.addStringOption('h', "-host", true, null, "Engine hostname"); -- CB
		ap.addStringOption('h', "-host", false,
						   CommonNetHandling.getLocalHostName(),
						   "Search Engine hostname");
		ap.addIntOption('p', "-port", true, null, "Engine port");
		ap.addIntOption('t', "-timeout", false, 30, "Handle check timeout");
		// Flags
		ap.addFlag('q', "-quiet", "Do not print statistics while running");
		
		try {
			ap.parse(argv);
		}
		catch (java.text.ParseException pe) {
			System.err.println(pe.getMessage());
			System.err.println(ap.usage());
			return;
		}
		
		if (ap.getFlag('?')) {
			System.err.println("Lightweight Bartering Grid -- "
				+ "search engine launcher\n\n" + ap.usage());
			return;
		}
		
		/* **************************************************************** */

		LightweightBarteringGrid.setMode(lbg.VirtualizationLevel.LIVE_MODE);
		
		LiveSearchEngineServer ses =
			new LiveSearchEngineServer(ap.strValueOf('i'),ap.strValueOf('h'),
									   ap.intValueOf('p'),ap.intValueOf('t'));
		ses.startService();
		
		if (!(ap.getFlag('q'))) {
			System.out.println("\n"+LightweightBarteringGrid.welcome()+
							   ses.toString());
		}

		// As the thread isn't a daemon, we can return here
	}
	
}

