/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SubmissionTimesDistribution.java

package lbg.middleware.util;

import lbg.common.*;
import lbg.common.exception.*;
import lbg.common.math.CommonMath;

/**
 * @author Cyril Briquet
 */
public class SubmissionTimesDistribution implements SubmissionTimesGenerator {

	/** Constructs a new submission times distribution-based generator.
	 */
	public SubmissionTimesDistribution(int inter_submission_lo,
									   int inter_submission_hi)
		throws GridException {
	
		if (inter_submission_lo < 0) {
			throw new GridException("SubmissionTimesDistribution(): "+
									"illegal Job inter-submission interval "+
									"low boundary");
		}
		if (inter_submission_hi < 0) {
			throw new GridException("SubmissionTimesDistribution(): "+
									"illegal Job inter-submission interval "+
									"high boundary");
		}
		if (inter_submission_lo > inter_submission_hi) {
			throw new GridException("SubmissionTimesDistribution(): "+
									"illegal Job inter-submission interval");
		}
	
		this.inter_submission_lo = inter_submission_lo;
		this.inter_submission_hi = inter_submission_hi;
	
	}

	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SubmissionTimesDistribution]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void waitBeforeNextSubmission() throws GridException {
		
		int inter_submission_t =
			CommonMath.sampleUniformDist(this.inter_submission_lo,
										 this.inter_submission_hi);
		if (inter_submission_t < 0) {
			throw new GridException("waitBeforeNextSubmission(): "+
									"corrupted Job inter-submission time");
		}
		
		ThreadPool.sleep(inter_submission_t);

	}

	public synchronized void skipWaitingBeforeFirstSubmission() {
		
	}

	// ****************************************************************

	public synchronized String summary() {

		StringBuilder sb = new StringBuilder();
		
		sb.append("every ").append(this.inter_submission_lo).append("-").
			append(this.inter_submission_hi).append(" seconds");

		return sb.toString();
		
	}

	// ****************************************************************
	
	private final int inter_submission_lo;
	private final int inter_submission_hi;

}

