/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedPeer.java

package lbg.peer;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.config.*;
import lbg.peer.core.*;
import lbg.peer.service.*;
import lbg.protocol.data.*;
import lbg.searchengine.service.*;
import lbg.simulator.*;
import java.util.logging.Logger;

/** Peer (SIM mode).
 * @author Cyril Briquet
 */
public class SimulatedPeer extends Peer {
	
	/** Creates a new Peer (SIM mode).
	 * @param peer_basic_config Peer basic configuration
	 * @param peer_network_config Peer network configuration
	 * @param peer_data_config Peer data configuration
	 * @param peer_strategy_config Peer strategy configuration
	 * @param peer_service_factory Peer service factory
	 * @param ctrlr_factory controller factory
	 * @param se_handle search engine handle
	 * @param env_ctrlr environment controller
	 * @param sim_idx Peer simulator index
	 */
	public SimulatedPeer(PeerBasicConfiguration peer_basic_config,
	     				 PeerNetworkConfiguration peer_network_config,
						 PeerDataConfiguration peer_data_config,
						 PeerStrategyConfiguration peer_strategy_config,
						 PeerServiceFactory peer_service_factory,
						 ControllerFactory ctrlr_factory,
						 SearchEngineHandle se_handle,
						 EnvironmentController env_ctrlr,int sim_idx)
		throws GridException {

		super(peer_basic_config,peer_network_config,peer_data_config,
			  peer_strategy_config,peer_service_factory,ctrlr_factory,
			  se_handle);
		
		// ****************

		if (env_ctrlr == null) {
			throw new GridException("SimulatedPeer(): illegal "+
									"Environment Controller");
		}
		if (sim_idx < 0) {
			throw new GridException("SimulatedPeer(): illegal "+
									"Peer simulator index");
		}

		env_ctrlr.setNegotiatorAndScheduler(sim_idx,
											super.negotiator,super.scheduler);

	}
	
	public String toString() {
	
		return CommonStringHandling.
			replaceTag(super.toString(),"[Peer","[SimulatedPeer");

	}

	// ****************************************************************

	/**
	 * @return null
	 */	 
	public GridDataManager gdm() {
		
		return null;
		
	}
	
	/**
	 * @return null
	 */	 
	public Logger logger() {
		
		return null;
		
	}

	// ****************************************************************

}

