/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// PeerBasicConfiguration.java

package lbg.peer.config;

import lbg.*;
import static lbg.VirtualizationLevel.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonStringHandling.*;
import java.util.Properties;

/**
 * @author Cyril Briquet
 */
public class PeerBasicConfiguration {

	public PeerBasicConfiguration(Properties props) throws GridException {
		
		if (props == null) {
			throw new GridException("PeerBasicConfiguration(): "+
									"illegal Properties");
		}
		
		this.PEER_ID = loadProperty("PEER_ID",props);
		this.SEARCH_TIMEOUT = loadInt(loadProperty("SEARCH_TIMEOUT",props));
		this.SCHEDULE_HEAD_JOB_ONLY = false;
			/*CommonFileHandling.loadBoolean(CommonFileHandling.
					loadProperty("SCHEDULE_HEAD_JOB_ONLY",props));*/
		
		// ****************
		
		checkProperties();

	}
	
	public PeerBasicConfiguration(String peer_id, int timeout)
								  /*boolean schedule_head_job_only)*/
			throws GridException {
		
		if (LightweightBarteringGrid.getMode() != SIM_MODE) {
			throw new GridException("PeerBasicConfiguration(): "+
									"wrong constructor");
		}

		if (peer_id == null) {
			throw new GridException("PeerBasicConfiguration(): "+
									"illegal Peer id");
		}
		
		this.PEER_ID = peer_id;
		this.SEARCH_TIMEOUT = timeout;
		this.SCHEDULE_HEAD_JOB_ONLY = true; /*schedule_head_job_only*/

		// ****************
		
		checkProperties();

	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[PeerBasicConfiguration]");
		sb.append(format(true));
		
		return sb.toString();
		
	}
	
	/** Outputs the PeerBasicConfiguration,
	 * formatted either as a property file or as a log file.
	 * @param log_format true to format PeerBasicConfiguration as a log file
	 * @return formatted PeerBasicConfiguration
	 */
	public String format(boolean log_format) {
		
		StringBuilder sb = new StringBuilder();

		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("PEER_ID = ");
		sb.append(this.PEER_ID);
		
		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("SEARCH_TIMEOUT = ");
		sb.append(this.SEARCH_TIMEOUT);

		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("SCHEDULE_HEAD_JOB_ONLY = ");
		sb.append(this.SCHEDULE_HEAD_JOB_ONLY);

		return sb.toString();

	}
	
	// ****************************************************************

	public String PEER_ID() {
	
		return this.PEER_ID;
		
	}

	// ****************************************************************

	private void checkProperties() throws GridException {

		if ((this.PEER_ID == null) || (this.PEER_ID.length() < 1)) {
			throw new GridException("checkProperties(): "+
									"illegal Peer id");
		}
		
		if (this.SEARCH_TIMEOUT < 0) {
			throw new GridException("checkProperties(): "+
									"illegal search timeout");
		}
		
	}

	// ****************************************************************

	private final String PEER_ID;
	public final int SEARCH_TIMEOUT;
	public final boolean SCHEDULE_HEAD_JOB_ONLY;

}

