/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// RandomizerConfiguration.java

package lbg.peer.config;

import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonStringHandling.*;
import java.util.Properties;

/**
 * @author Cyril Briquet
 */
public class RandomizerConfiguration implements Cloneable {

	public RandomizerConfiguration(Properties props) throws GridException {
		
		if (props == null) {
			throw new GridException("RandomizerConfiguration(): "+
									"illegal Properties");
		}
		
		this.SIMULATION_SEED = loadInt(loadProperty("SIMULATION_SEED",props));
		
	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[RandomizerConfiguration]");
		sb.append(format(true));
		
		return sb.toString();
		
	}
	
	/** Outputs the RandomizerConfiguration,
	 * formatted either as a property file or as a log file.
	 * @param log_format true to format RandomizerConfiguration as a log file
	 * @return formatted RandomizerConfiguration
	 */
	public String format(boolean log_format) {
		
		StringBuilder sb = new StringBuilder();

		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("SIMULATION_SEED     = ");
		sb.append(this.SIMULATION_SEED);
		
		return sb.toString();

	}
	
	// ****************************************************************

	public int SIMULATION_SEED() {

		return this.SIMULATION_SEED;
		
	}

	// ****************************************************************

	@Override
	public synchronized Object clone() {

		RandomizerConfiguration randomizer_config = null;
		
		try {
			randomizer_config = (RandomizerConfiguration)super.clone();
		}
		catch (CloneNotSupportedException e) {
			throw new InternalError("clone(): cannot clone "+
									"RandomizerConfiguration");
		}
		
		return randomizer_config;
		
	}

	// ****************************************************************
	
	private final int SIMULATION_SEED;

}

