/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SelfEventProcessorThread.java

package lbg.peer.core;

import lbg.*;
import lbg.common.exception.*;
import lbg.peer.*;

/**
 * @author Cyril Briquet
 */
public class SelfEventProcessorThread implements Runnable {

	public SelfEventProcessorThread(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("SelfEventProcessorThread(): "+
									"illegal Peer");
		}
		this.managed_peer = managed_peer;
		this.running = false;

	}

	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SelfEventProcessorThread ");
		sb.append(this.managed_peer.id());
		sb.append("]\n");

		return sb.toString();
		
	}
	
	// ****************************************************************

	/** Runnable implementation.
	 */
	public void run() {

		try {
			synchronized(this) {
				// You really don't want too many instances executed
				// by the Peer self-events timer, at the rate of 1 per second,
				// if they are blocked on rms sync'... sort of cumulative effect
				if (this.running == true) {
					return;
				}
				else {
					this.running = true;
				}
			}
			synchronized (this.managed_peer.rms()) {
				this.managed_peer.processSelfEvents();
				synchronized(this) {
					this.running = false;
				}
			}
		}
		catch (GridException e) {
			LightweightBarteringGrid.handleGridException(e);
		}
		
	}

	// ****************************************************************

	private final Peer managed_peer;
	private boolean running;

}

