/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NegotiatorController.java

package lbg.peer.core.negotiator;

import lbg.common.exception.*;
import lbg.peer.*;

/**
 * @author Cyril Briquet
 */
public abstract class NegotiatorController {

	public NegotiatorController(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NegotiatorController(): illegal Peer");
		}
		this.managed_peer = managed_peer;

		this.gen_supplying_requests_flag = false;
		this.eval_supplying_requests_flag = false;

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[NegotiatorController ");
		sb.append(this.managed_peer.id());
		sb.append("]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void activateSupplyingRequestsGeneration()
		throws GridException {
	
		this.gen_supplying_requests_flag = true;
		awakeNegotiator();
		
	}

	public synchronized void activateSupplyingRequestsEvaluation()
		throws GridException {
	
		this.eval_supplying_requests_flag = true;
		awakeNegotiator();
		
	}

	// ****************************************************************

	public synchronized boolean couldNegotiate() {
	
		return  this.gen_supplying_requests_flag ||
				this.eval_supplying_requests_flag;
		
	}

	// ****************************************************************

	public synchronized void
		getAndResetControlFlags(NegotiatorControlFlags ctrl_flags){
		
		ctrl_flags.setFlagsIfTrue(this.gen_supplying_requests_flag,
								  this.eval_supplying_requests_flag);
		
		this.gen_supplying_requests_flag = false;
		this.eval_supplying_requests_flag = false;

	}

	// ****************************************************************

	public abstract void awakeNegotiator() throws GridException;
	
	// ****************************************************************

	private Peer managed_peer;

	private boolean gen_supplying_requests_flag;
	private boolean eval_supplying_requests_flag;
	
}

