/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// RequestContainer.java

package lbg.peer.core.qms;

import lbg.common.exception.*;
import lbg.peer.register.learning.consumption.*;
import lbg.peer.register.learning.db.TaskSchedulingContext;
import lbg.task.*;

/** A RequestContainer stores a Task that is scheduled and its scheduling id.
 * It may also store its scheduling context
 * and the Consumption and Data trackers of its owner Job.
 * @author Cyril Briquet
 */
public class RequestContainer {

	public RequestContainer(Task t,Integer task_scheduling_id)
		throws GridException {
		
		if (t == null) {
			throw new GridException("RequestContainer(): illegal Task");
		}
		if (task_scheduling_id == null) {
			throw new GridException("RequestContainer(): "+
									"illegal Task scheduling id");
		}
		
		this.t = t;
		this.task_scheduling_id = task_scheduling_id;
		this.tsc = null;
		this.job_consumption_outcome_tracker = null;
		this.job_data_tracker = null;
		
	}

	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[RequestContainer]");
		
		return sb.toString();
		
	}
	
	// ****************************************************************

	public Task getTask() {
		
		return this.t;
		
	}
	
	public Integer getTaskSchedulingID() {
		
		return this.task_scheduling_id;
		
	}

	public boolean hasSchedulingContext() {
		
		return this.tsc != null;
		
	}

	// ****************************************************************

	public void setSchedulingContext(TaskSchedulingContext tsc)
		throws GridException {
		
		if (this.tsc != null) {
			throw new GridException("setSchedulingContext(): "+
									"Task Scheduling Context already set");
		}
		if (tsc == null) {
			throw new GridException("setSchedulingContext(): "+
									"illegal Task Scheduling Context");
		}

		this.tsc = tsc;
		
	}

	public TaskSchedulingContext getSchedulingContext() throws GridException {
		
		if (this.tsc == null) {
			throw new GridException("getSchedulingContext(): "+
									"Task Scheduling Context yet to be set");
		}
		
		return this.tsc;
		
	}

	public void
		setJobConsumptionOutcomeTracker(JobConsumptionOutcomeTracker
										job_consumption_outcome_tracker)
		throws GridException {
		
		if (this.job_consumption_outcome_tracker != null) {
			throw new GridException("setJobConsumptionOutcomeTracker(): "+
									"Job Consumption tracker already set");
		}
		if (job_consumption_outcome_tracker == null) {
			throw new GridException("setJobConsumptionOutcomeTracker(): "+
									"illegal Job Consumption tracker");
		}

		this.job_consumption_outcome_tracker = job_consumption_outcome_tracker;
		
	}

	public JobConsumptionOutcomeTracker getJobConsumptionOutcomeTracker()
		throws GridException {
		
		if (this.job_consumption_outcome_tracker == null) {
			throw new GridException("getJobConsumptionOutcomeTracker(): "+
									"Job Consumption tracker yet to be set");
		}
		
		return this.job_consumption_outcome_tracker;
		
	}

	public void
		setJobConsumptionDataTracker(JobConsumptionDataTracker
										  job_data_tracker)
		throws GridException {
		
		if (this.job_data_tracker != null) {
			throw new GridException("setJobConsumptionDataTracker(): "+
									"Job Data tracker already set");
		}
		if (job_data_tracker == null) {
			throw new GridException("setJobConsumptionDataTracker(): "+
									"illegal Job Data tracker");
		}

		this.job_data_tracker = job_data_tracker;
		
	}

	public JobConsumptionDataTracker getJobConsumptionDataTracker()
		throws GridException {
		
		if (this.job_data_tracker == null) {
			throw new GridException("getJobConsumptionDataTracker(): "+
									"Job Data tracker yet to be set");
		}
		
		return this.job_data_tracker;
		
	}

	// ****************************************************************

	private final Task t;
	private final Integer task_scheduling_id;

	private       TaskSchedulingContext tsc;
	private       JobConsumptionOutcomeTracker job_consumption_outcome_tracker;
	private       JobConsumptionDataTracker job_data_tracker;

}

