/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ConsumptionTaskID.java

package lbg.peer.core.qms.prequeue;

import lbg.common.exception.*;
import java.io.Serializable;

/** Consumption Task id in Supplying space.
 * <p>When a Consumption Task submitted by a Consumer Peer
 * is accepted as a Supplying Task by a Supplier Peer,
 * the latter returns the Task id in its id space,
 * so that the Consumer has the possibility to cancel the Task later.
 * @author Cyril Briquet
 */
public class ConsumptionTaskID implements Serializable {

	/** Constructs a legal new Consumption Task id.
	 * @param job_id target Job id
	 * @param bot_id target BoT id
	 * @exception GridException if a parameter is illegal
	 */
	public ConsumptionTaskID(int job_id,int bot_id) throws GridException {

		if (job_id < 0) {
			throw new GridException("ConsumptionTaskID(): illegal Job id");
		}
		if (bot_id < 0) {
			throw new GridException("ConsumptionTaskID(): illegal BoT id");
		}
		
		this.job_id = job_id;
		this.bot_id = bot_id;
		
	}

	/** Constructs an illegal new Consumption Task id, i.e. to designate
	 * a non-existent illegal Consumption Task id.
	 */ // let's call that a "no-Task", a la Dune ;)
	public ConsumptionTaskID() {
		
		this.job_id = this.bot_id = -1;
		
	}

	// ****************************************************************

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[ConsumptionTaskID]");
		
		sb.append(" Supplying space Job id=");
		sb.append(this.job_id);
		sb.append(", Supplying space BoT id=");
		sb.append(this.bot_id);
		
		return sb.toString();
		
	}
	
	// ****************************************************************

	public final int job_id;
	public final int bot_id;
	
	// ****************************************************************

	static final long serialVersionUID = 4390943659152872516L;

}

