/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveJobPreQueue.java

package lbg.peer.core.qms.prequeue;

import lbg.*;
import lbg.common.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonStringHandling.getStackTrace;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.workflow.*;

import java.util.concurrent.LinkedBlockingQueue;

public class LiveJobPreQueue extends JobPreQueue implements Runnable {

	public LiveJobPreQueue(Peer managed_peer,Scheduler scheduler,
						   boolean enable_ttg)
		throws GridException {

		super(managed_peer,scheduler,enable_ttg);
		
		if (managed_peer == null) {
			throw new GridException("LiveJobPreQueue(): illegal Peer");
		}
		
		this.managed_peer = managed_peer;
		this.thread_pool =
			new ThreadPool(this,1,true,true,"JobPreQueue-daemon");
		this.q = new LinkedBlockingQueue<RequestHolder>();
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[JobPreQueue","[LiveJobPreQueue"));

		sb.append("\n   ->  ");
		sb.append("prequeue size = ");
		sb.append(this.q.size());

		return sb.toString();

	}

	// ****************************************************************

	public synchronized void startService() throws GridException {
		
		this.thread_pool.startService();
		
	}
	
	/** Runnable implementation.
	 */
	public void run() {

		for ( ; ; ) {
			try {
				super.actuallyTransferJob(this.q.take());
			}
			catch (Throwable thr) {
				this.managed_peer.logger().
					info("JobPreQueue.transferJob(): "+getStackTrace(thr));
			}
		}
		
	}
	
	/**
	 * @return JobPreQueue size
	 */
	public int size() {

		return this.q.size();
		
	}

	// ****************************************************************

	protected void transferJob(RequestHolder req) throws GridException {
		
		if (req == null) {
			throw new GridException("transferJob(): illegal request");
		}

		try {
			this.q.put(req);
		}
		catch (InterruptedException e) {
			throw new GridException(e);
		}
		
	}
	
	// ****************************************************************

	private final Peer managed_peer;
	private final ThreadPool thread_pool;
	private final LinkedBlockingQueue<RequestHolder> q;

}

