/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedJobPreQueue.java

package lbg.peer.core.qms.prequeue;

import lbg.common.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.workflow.*;

public class SimulatedJobPreQueue extends JobPreQueue {

	public SimulatedJobPreQueue(Peer managed_peer,Scheduler scheduler,
								boolean enable_ttg)
		throws GridException {

		super(managed_peer,scheduler,enable_ttg);
		
		if (managed_peer == null) {
			throw new GridException("SimulatedJobPreQueue(): illegal Peer");
		}
		
		this.managed_peer = managed_peer;
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[JobPreQueue",
							   "[SimulatedJobPreQueue"));

		return sb.toString();

	}

	// ****************************************************************

	/**
	 * @return nothing
	 * @exception GridException as size() is not supported in SIM mode
	 */
	public int size() throws GridException {
	
		throw new GridException("size(): unsupported operation");
		
	}
	
	// ****************************************************************

	protected synchronized void transferJob(RequestHolder req)
		throws GridException {
		
		super.actuallyTransferJob(req);
		
	}

	// ****************************************************************

	private final Peer managed_peer;

}

