/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LocalQueueCursor.java

package lbg.peer.core.qms.queue;

import lbg.common.exception.*;
import lbg.peer.core.qms.*;
import lbg.task.*;

/** A Local queue cursor allows to memorize
 * which Task in the Local Tasks queue has been last selected,
 * when scheduling Local Tasks as Consumption Tasks.
 * @author Cyril Briquet
 */
public class LocalQueueCursor {

	public LocalQueueCursor() {

		clear();

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[LocalQueueCursor]");
		sb.append(" current Job id=");
		sb.append(this.current_job_id);
		sb.append(", current BoT id=");
		sb.append(this.current_bot_id);
		sb.append(", current Task scheduling id=");
		sb.append(this.current_task_scheduling_id_as_key);
		
		return sb.toString();
		
	}

	// ****************************************************************

	public int jobID() {
		
		return this.current_job_id;
		
	}
	
	public int jobIDAsKey() {
		
		return this.current_job_id_as_key;
		
	}

	public int boTID() {
		
		return this.current_bot_id;
		
	}
	
	public Integer taskSchedulingIDAsKey() {
		
		return this.current_task_scheduling_id_as_key;
		
	}
	
	// ****************************************************************

	public void clear() {
		
		this.current_job_id = -1;
		this.current_job_id_as_key = MINUS_ONE;
		this.current_bot_id = -1;
		this.current_task_scheduling_id_as_key = MINUS_ONE;
		
	}

	public void update(RequestContainer rc) throws GridException {
		
		if (rc == null) {
			throw new GridException("update(): illegal Task container");
		}

		Task t = rc.getTask();
		if (t == null) {
			throw new GridException("update(): illegal Task");
		}
		
		Integer task_scheduling_id = rc.getTaskSchedulingID();
		if (task_scheduling_id == null) {
			throw new GridException("update(): illegal Task scheduling id");
		}

		this.current_job_id = t.jobID();
		this.current_job_id_as_key = t.jobIDAsKey();
		this.current_bot_id = t.botID();
		this.current_task_scheduling_id_as_key = task_scheduling_id;
		
	}

	// ****************************************************************

	private int current_job_id;
	private Integer current_job_id_as_key;

	private int current_bot_id;

	private Integer current_task_scheduling_id_as_key;
	
	private final Integer MINUS_ONE = Integer.valueOf(-1);

}

