/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SchedulerControlFlags.java

package lbg.peer.core.scheduler;

/**
 * @author Cyril Briquet
 */
public class SchedulerControlFlags {

	public SchedulerControlFlags() {
	
		this.local_scheduling_flag = false;
		this.supplying_scheduling_flag = false;
		this.consumption_scheduling_flag = false;

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SchedulerControlFlags]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void clear() {
	
		this.local_scheduling_flag = false;
		this.supplying_scheduling_flag = false;
		this.consumption_scheduling_flag = false;
		
	}
	
	/** Sets flags of this Peer with target flags.
	 * @deprecated
	 */
	@Deprecated
	public synchronized void setFlags(boolean local_scheduling_flag,
	 								  boolean supplying_scheduling_flag,
									  boolean consumption_scheduling_flag) {
		
		this.local_scheduling_flag = local_scheduling_flag;
	 	this.supplying_scheduling_flag = supplying_scheduling_flag;
		this.consumption_scheduling_flag = consumption_scheduling_flag;

	}

	/** Sets flags of this Peer with target flags.
	 * <p>Note: as opposed to setFlags(), the number of flags set to true
	 * can only increase with setFlagsIfTrue().
	 * It exists because, in SIM mode, controller.getAndResetControlFlags()
	 * can be called several times before the collected flags
	 * are actually processed.
	 * Calling setFlagsIfTrue() in LIVE mode requires that
	 * the controlled Thread clears its internal flags structure after use.
	 */
	public synchronized void
		setFlagsIfTrue(boolean local_scheduling_flag,
	 				   boolean supplying_scheduling_flag,
					   boolean consumption_scheduling_flag) {
		
		this.local_scheduling_flag =
			this.local_scheduling_flag || local_scheduling_flag;
	 	this.supplying_scheduling_flag =
			this.supplying_scheduling_flag || supplying_scheduling_flag;
		this.consumption_scheduling_flag =
			this.consumption_scheduling_flag || consumption_scheduling_flag;

	}

	/** Sets target flags with flags of this Peer.
	 * @deprecated
	 */
	@Deprecated
	public synchronized void copyFlags(SchedulerControlFlags flags) {
		
		flags.setFlags(this.local_scheduling_flag,
					   this.supplying_scheduling_flag,
					   this.consumption_scheduling_flag);
					   
	}

	// ****************************************************************

	public synchronized boolean getLocalSchedulingFlag() {
		
		return this.local_scheduling_flag;

	}
	
	public synchronized boolean getSupplyingSchedulingFlag() {
		
		return this.supplying_scheduling_flag;

	}

	public synchronized boolean getConsumptionSchedulingFlag() {
		
		return this.consumption_scheduling_flag;

	}
	
	// ****************************************************************
	
	private boolean local_scheduling_flag;
	private boolean supplying_scheduling_flag;
	private boolean consumption_scheduling_flag;
	
}

