/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SchedulerController.java

package lbg.peer.core.scheduler;

import lbg.common.exception.*;
import lbg.peer.*;

/**
 * @author Cyril Briquet
 */
public abstract class SchedulerController {

	public SchedulerController(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("SchedulerController(): illegal Peer");
		}
		this.managed_peer = managed_peer;

		this.local_scheduling_flag = false;
		this.supplying_scheduling_flag = false;
		this.consumption_scheduling_flag = false;

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SchedulerController ");
		sb.append(this.managed_peer.id());
		sb.append("]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void activateLocalScheduling()
		throws GridException {
	
		this.local_scheduling_flag = true;
		awakeScheduler();
		
	}
	
	public synchronized void activateSupplyingScheduling()
		throws GridException {
	
		this.supplying_scheduling_flag = true;
		awakeScheduler();
		
	}

	public synchronized void activateConsumptionScheduling()
		throws GridException {
	
		this.consumption_scheduling_flag = true;
		awakeScheduler();
		
	}

	public synchronized void activateLocalAndConsumptionScheduling()
		throws GridException {
	
		this.local_scheduling_flag = true;
		this.consumption_scheduling_flag = true;
		awakeScheduler();
		
	}

	public synchronized void activateLocalAndSupplyingScheduling()
		throws GridException {
	
		this.local_scheduling_flag = true;
		this.supplying_scheduling_flag = true;
		awakeScheduler();
		
	}

	public synchronized void activateAllScheduling()
		throws GridException {
	
		this.local_scheduling_flag = true;
		this.supplying_scheduling_flag = true;
		this.consumption_scheduling_flag = true;
		awakeScheduler();
		
	}

	// ****************************************************************

	public synchronized boolean couldSchedule() {
	
		return  this.local_scheduling_flag ||
			this.supplying_scheduling_flag || this.consumption_scheduling_flag;
		
	}
	
	// ****************************************************************

	public synchronized void
		getAndResetControlFlags(SchedulerControlFlags ctrl_flags) {
	
		ctrl_flags.setFlagsIfTrue(this.local_scheduling_flag,
								  this.supplying_scheduling_flag,
								  this.consumption_scheduling_flag);
		this.local_scheduling_flag = false;
		this.supplying_scheduling_flag = false;
		this.consumption_scheduling_flag = false;
		
	}

	// ****************************************************************

	public abstract void awakeScheduler() throws GridException;
	
	// ****************************************************************

	private Peer managed_peer;

	private boolean local_scheduling_flag;
	private boolean supplying_scheduling_flag;
	private boolean consumption_scheduling_flag;
	
}

