/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedSchedulerController.java

package lbg.peer.core.scheduler;

import lbg.*;
import static lbg.VirtualizationLevel.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.*;
import lbg.simulator.*;

/**
 * @author Cyril Briquet
 */
public class SimulatedSchedulerController extends SchedulerController {

	public SimulatedSchedulerController(Peer managed_peer,
										EnvironmentController env_ctrlr,
										String PEER_BASE_NAME)
		throws GridException {

		super(managed_peer);
		
		if (LightweightBarteringGrid.getMode() == LIVE_MODE) {
			throw new GridException("SimulatedSchedulerController(): "+
									"unsupported mode");
		}

		if (env_ctrlr == null) {
			throw new GridException("SimulatedSchedulerController(): "+
									"illegal EnvironmentController");
		}
				
		if (PEER_BASE_NAME == null) {
			throw new GridException("SimulatedSchedulerController(): "+
									"illegal Peer base name");
		}

		this.env_ctrlr = env_ctrlr;
		this.peer_int_id =
			Integer.parseInt(managed_peer.id().
								substring(PEER_BASE_NAME.length()));

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[SchedulerController]",
							   "[SimulatedSchedulerController]"));
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void awakeScheduler() throws GridException {
	
		if (couldSchedule()) {
			this.env_ctrlr.notifyEnvironmentController(this.peer_int_id,this);
		}
		else { // debugging
			throw new GridException("awakeScheduler(): could not schedule, "+
									"why did you awake me ?");
		}
		
	}
	
	// ****************************************************************

	private final EnvironmentController env_ctrlr;
	private final int peer_int_id;

}

