/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// RunningLocalTaskManager.java

package lbg.peer.core.xms;

import lbg.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonStringHandling.DUMMY_LOG;
import lbg.peer.*;
import lbg.task.*;
import java.util.*;

/**
 * @author Cyril Briquet
 */
public class RunningLocalTaskManager extends RunningTaskManager {

	public RunningLocalTaskManager(Peer managed_peer,
								   TaskComparator task_cmp,
								   String task_runtime_data_type)
		throws GridException {

		super(managed_peer,task_cmp,task_runtime_data_type);
		
		if (managed_peer == null) {
			throw new GridException("RunningLocalTaskManager(): "+
									"illegal Peer");
		}
		
		this.managed_peer = managed_peer;

	}

	public synchronized String toString() {
	
		return CommonStringHandling.
			replaceTag(super.toString(),"RunningTaskManager",
										"RunningConsumptionTaskManager");
		
	}
	
	// ****************************************************************

	/* Preempts timed-out Local Tasks, i.e. running, timed-out Local Tasks
	 * are requeued.
	 * @return true if at least one Local Task has been preempted
	public synchronized boolean processTimedOutTasks() throws GridException {
		
		return processTimedOutTasks(true);
		
	}*/

	/** Processes timed-out Tasks.
	 * @return true if at least one Task has been preempted or cancelled
	 */
	public synchronized boolean processTimedOutTasks() throws GridException {
		
		if (areSomeTasksRunning() == false) {
			return false;
		}

		ArrayList<?> al = listTimedOutTasks();

		// Actually cancel the time-out Local Tasks
		for (Object o : al) {
			TaskRuntimeData trd = (TaskRuntimeData)o;
			Task t = trd.getTask();
			boolean do_cancel = trd.getTimeOutActionTag();

			if (do_cancel) { // Cancel the Local Task
				this.managed_peer.xms().
					cancelLocalTaskOnLocalResource(t,DUMMY_LOG);
			}
			else { // Preempt the Local Task
				this.managed_peer.xms().
					preemptLocalTaskOnLocalResource(t,DUMMY_LOG);
			}
			
			//this.remove(trd.getTask()); -- NO, already done by tkm.x()
		}
		
		return al.size() > 0;
		
	}

	// ****************************************************************

	private final Peer managed_peer;
	
}

