/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// TaskRuntimeDataFactory.java

package lbg.peer.core.xms;

import lbg.common.exception.*;
import lbg.peer.service.*;
import static lbg.common.math.CommonMath.generateHashCode;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public enum TaskRuntimeDataFactory {

	// ****************************************************************
	
	ConsumptionTaskRuntimeData {
		public TaskRuntimeData
			createTaskRuntimeData(Task t,long time_out,
							  	  ExternalPeerHandle peer_handle,
								  String supplier_id,boolean do_cancel)
			throws GridException {
		
			return new ConsumptionTaskRuntimeData(t,time_out,peer_handle,
												  supplier_id,do_cancel);
		
		}

	},
	
	LocalTaskRuntimeData {
		public TaskRuntimeData
			createTaskRuntimeData(Task t,long time_out,
							  	  ExternalPeerHandle peer_handle,
								  String supplier_id,boolean do_cancel)
			throws GridException {
		
			return new LocalTaskRuntimeData(t,time_out,peer_handle,
											supplier_id,do_cancel);
		
		}

	},
	
	SupplyingTaskRuntimeData {
		public TaskRuntimeData
			createTaskRuntimeData(Task t,long time_out,
							  	  ExternalPeerHandle peer_handle,
								  String supplier_id,boolean do_cancel)
			throws GridException {
		
			return new SupplyingTaskRuntimeData(t,time_out,peer_handle,
												supplier_id,do_cancel);
		
		}

	};

	// ****************************************************************

	public abstract TaskRuntimeData
		createTaskRuntimeData(Task t,long time_out,
							  ExternalPeerHandle peer_handle,
							  String supplier_id,boolean do_cancel)
		throws GridException;

}

