/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// TestPeerProfile.java

package lbg.peer.register;

import lbg.common.exception.*;
import lbg.common.math.*;
import lbg.peer.*;
import lbg.peer.register.bartering.*;
import lbg.peer.register.learning.db.*;
import lbg.peer.register.negotiation.*;
import lbg.peer.service.*;
import lbg.peer.strategy.accounting.*;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public class TestPeerProfile extends PeerProfile {

	public TestPeerProfile(String profiled_peer_id,String managed_peer_id)
		throws GridException {

		if (profiled_peer_id == null) {
			throw new GridException("TestPeerProfile(): "+
									"illegal profiled Peer id");
		}
		if (managed_peer_id == null) {
			throw new GridException("TestPeerProfile(): "+
									"illegal managed Peer id");
		}

		this.profiled_peer_handle = new TestPeerHandle(profiled_peer_id);
		this.managed_peer_id = managed_peer_id;
		this.profiled_peer_id = profiled_peer_id;
		
		this.negotiation_profile = null;
/*	new PeerNegotiationProfile(this.managed_peer,this.profiled_peer);*/
		this.bartering_profile = null;
			/*new PeerBarteringProfile(this.managed_peer,
									 this.profiled_peer,
									 accountant);*/

		this.hashcode = Integer.MIN_VALUE;

	}
	
	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[TestPeerProfile of ");
		sb.append(this.profiled_peer_id);
		sb.append(",  by ");
		sb.append(this.managed_peer_id);
		sb.append("]");
		
		return sb.toString();
		
	}
	
	@Override
	public int compareTo(PeerProfile other) {
	
		String self_id = this.profiled_peer_id;
		String other_id = other.id();
		
		return self_id.compareToIgnoreCase(other_id);
		
	}
	
	@Override
	public boolean equals(Object obj) {
		
		if (obj instanceof PeerProfile == false) {
			return false;
		}
		
		return (this.compareTo((PeerProfile)obj) == 0);
		
	}

	@Override
	public int hashCode() {
	
		if (this.hashcode == Integer.MIN_VALUE) {
			this.hashcode = CommonMath.generateHashCode(this.profiled_peer_id);
		}
		return this.hashcode;
	
	}

	// ****************************************************************

	public synchronized String id() {
		
		return this.profiled_peer_id;
		
	}

	public synchronized ExternalPeerHandle getHandle() {
		
		return this.profiled_peer_handle;
		
	}
			
	public synchronized PeerNegotiationProfile getNegotiationProfile() {
		
		return this.negotiation_profile;
		
	}
	
	public synchronized PeerBarteringProfile getBarteringProfile() {
		
		return this.bartering_profile;
		
	}

	public synchronized PeerInteractionsDataBase getInteractionsDataBase()
		throws GridException {
		
		throw new GridException("not implemented");
		
	}

	// ****************************************************************

	public synchronized int getWaitingJobsCount() throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public synchronized int increaseWaitingJobsCount() throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public synchronized int decreaseWaitingJobsCount() throws GridException {
		
		throw new GridException("not implemented");
		
	}

	// ****************************************************************

	public synchronized TaskSchedulingContext
		createConsumptionTaskSchedulingContext(Task t) throws GridException {
		
		throw new GridException("not implemented");
		
	}

	public synchronized TaskSchedulingContext
		createSupplyingTaskSchedulingContext(Task t) throws GridException {

		throw new GridException("not implemented");
		
	}

	// ****************************************************************

	private final TestPeerHandle profiled_peer_handle;
	private final String profiled_peer_id;
	private final String managed_peer_id;

	private final PeerNegotiationProfile       negotiation_profile;
	private final TestPeerBarteringProfile     bartering_profile;

	private int hashcode;

}

