/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ConsumptionDataTracker.java

package lbg.peer.register.learning.consumption;

import lbg.common.exception.*;
import lbg.task.*;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

/** A ConsumptionDataTracker tracks the Local data known
 * to have been donwloaded by Supplier Peers.
 * <p>The tracked data were required
 * by successfully completed Consumption Tasks.
 * <p>To each data id is associated the set of Supplier Peers
 * which have downloaded the data.
 * <p>The tracked data can be searched to locate, and rank Peers
 * that may still have some Resources holding the data in their data cache.
 * @author Cyril Briquet
 */
public interface ConsumptionDataTracker {

	public void trackData(String supplier_peer,Task t) throws GridException;

	public Map<Long,Set<String>> rankPeers(Task t) throws GridException;

	public int countTrackedData();

	public Iterator<String> trackedSuppliers(String data_id)
		throws GridException;

}

