/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// JobConsumptionDataTracker.java

package lbg.peer.register.learning.consumption;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.common.math.*;

/** A JobConsumptionDataTracker tracks the Local data known
 * to have been downloaded by Supplier Peers.
 * <p>The tracked data were required
 * by successfully completed Consumption Tasks.
 * <p>To each data id is associated the set of Supplier Peers
 * which have downloaded the data.
 * <p>The tracked data can be searched to locate, and rank Peers
 * that may still have some Resources holding the data in their data cache.
 * @author Cyril Briquet
 */
public class JobConsumptionDataTracker
	extends PeerConsumptionDataTracker implements ConsumptionDataTracker {

	public JobConsumptionDataTracker(String owner_peer_id,int job_id)
		throws GridException {

		super(128);

		if (owner_peer_id == null) {
			throw new GridException("PeerConsumptionDataTracker(): "+
									"illegal Peer id");
		}
		if (job_id < 0) {
			throw new GridException("JobConsumptionDataTracker(): "+
									"illegal id");
		}
		
		this.owner_peer_id = owner_peer_id;
		this.job_id = job_id;

	}

	public synchronized String toString() {

		String s = super.toString();

		String old_tag = "[PeerLevelDataTracker] submitter=";

		StringBuilder sb = new StringBuilder();
		sb.append("[JobConsumptionDataTracker] ");
		sb.append(" Job id=");
		sb.append(this.job_id);
		sb.append(", submitter=");
		sb.append(this.owner_peer_id);
		String new_tag = sb.toString();

		return CommonStringHandling.replaceTag(s,old_tag,new_tag);
		
	}
	
	// ****************************************************************

	private final String owner_peer_id;
	private final int job_id;
	
	// ****************************************************************

}

