/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// PeerInteractionsDataBaseFactory.java

package lbg.peer.register.learning.db;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.register.learning.db.dummy.*;
import lbg.peer.service.*;

/**
 * @author Cyril Briquet
 */	
public class PeerInteractionsDataBaseFactory {

	/** Creates a new PeerInteractionsDataBaseFactory.
	 */
	public PeerInteractionsDataBaseFactory() {
		 
	}
	
	public String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append("[PeerInteractionsDataBaseFactory]");
		
		return sb.toString();

	}

	// ****************************************************************

	/** Creates a new PeerInteractionsDataBase.
	 * <p>Can be called at most once.
	 * @param managed_peer managed Peer
	 * @param profiled_peer profiled Peer
	 * @exception GridException if a parameter is illegal
	 */
	public PeerInteractionsDataBase
		createPeerInteractionsDataBase(Peer managed_peer,
									   ExternalPeerHandle profiled_peer)
		throws GridException {
		
		if (managed_peer == null) {
			throw new GridException("createPeerInteractionsDataBase(): "+
									"illegal managed Peer");
		}
		if (profiled_peer == null) {
			throw new GridException("createPeerInteractionsDataBase(): "+
									"illegal profiled Peer");
		}

		PeerInteractionsDataBase peer_interactions_db = null;
		
		peer_interactions_db = new DummyPeerInteractionsDataBase();
		
		return peer_interactions_db;
		
	}
	
}

