/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// TaskSchedulingContext.java

package lbg.peer.register.learning.db;

import lbg.common.exception.*;
import lbg.peer.core.qms.*;
import lbg.peer.register.learning.db.meta.*;
import lbg.task.*;

/** A TaskSchedulingContext holds the scheduling context of a given Task.
 * <p>During Task execution, it is stored into the BoT holding the given Task
 * (both the BoT on the Consumer and the BoT of the Suppliers)
 * until it is completed.
 * <p>Upon Task completion or cancellation, this data is augmented
 * with additional, Task outcome-related information,
 * and then stored into the PeerRegister
 * so that it can be mined by the Scheduler and Negotiators
 * so as to improve their decision making.
 * <p>A TaskSchedulingContext may be built for each Peer considered
 * by a Negotiator for the scheduling of the given Task,
 * so that possible Supplier Peers for the Consumption Task may be ranked
 * according to the prediction given by the reliability model.
 * <p>The TaskSchedulingContext of the selected Peer must be explicitely stored
 * into the RequestContainer (itself stored in the given Task's owner BoT)
 * of the given Task,
 * so that it can be automatically added to the Interactions DataBase
 * upon Task completion/cancellation.
 * @author Cyril Briquet
 */
public interface TaskSchedulingContext {

	public InteractionInstance getInteractionForClassification();
	
	public InteractionInstance getInteractionForRegression();
		
	public TaskOutcome predictedTaskOutcome();

	public double predictedResponseTime();
	
	public void setOutcome(Task t,long xstart_time,RequestType rt)
		throws GridException;

}

