/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// DummyPeerInteractionsDataBase.java

package lbg.peer.register.learning.db.dummy;

import lbg.common.exception.*;
import lbg.peer.register.*;
import lbg.peer.register.learning.db.*;

/**
 * @author Cyril Briquet
 */	
public class DummyPeerInteractionsDataBase implements PeerInteractionsDataBase {

	public DummyPeerInteractionsDataBase() throws GridException {
		
  		this.is_tscf_created = false;

	}
	
	public String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append("[DummyPeerInteractionsDataBase]");
		
		return sb.toString();

	}

	// ****************************************************************

	/** Does not create a new TaskSchedulingContextFactory.
	 * <p>Can be called at most once.
	 * @return null
	 * @exception GridException if a parameter is illegal,
	 * or method has been called more than once
	 */
	public TaskSchedulingContextFactory
		createTaskSchedulingContextFactory(PeerProfile profiled_peer_profile)
		throws GridException {
			
		if (is_tscf_created) {
			throw new GridException("createTaskSchedulingContextFactory(): "+
									"Task Scheduling Context Factory "+
									"already created");
		}
		
		this.is_tscf_created = true;

		return null;
		
	}

	/**
	 * @exception UnsupportedOperationException
	 * because this method is not supported
	 */
	public void addSupplyingInteraction(TaskSchedulingContext tsc)
		throws GridException {
		
		throw new UnsupportedOperationException("addSupplyingInteraction(): "+
												"dummy implementation");
		
	}
	
	/**
	 * @exception UnsupportedOperationException
	 * because this method is not supported
	 */
	public void addConsumptionInteraction(TaskSchedulingContext tsc,
										  boolean is_task_completed,
										  boolean is_predict_correct)
		throws GridException {
		
		throw new UnsupportedOperationException("addConsumptionInteraction(): "+
												"dummy implementation");

	}
	
	// ****************************************************************

	private boolean is_tscf_created;

}

