/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// InteractionAttributes.java

package lbg.peer.register.learning.db.meta;

import lbg.common.exception.*;
import lbg.peer.register.bartering.*;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public enum InteractionAttributes {

	/** Favors balance of target Peer.
	 */
	A_FAVORS_BALANCE {                        // 0x00
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getFavorsBalance();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total favors consumed from target Peer.
	 */
	A_TOTAL_CONSUMED_FAVORS {                 // 0x01
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalConsumedFavors();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total favors supplied to target Peer.
	 */
	A_TOTAL_SUPPLIED_FAVORS {                 // 0x02
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException  {

			double v = peer_bp.getTotalSuppliedFavors();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** to be removed -- Total power consumed from target Peer.
	 * /
	A_TOTAL_CONSUMED_POWER {                  // 0x03
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalConsumedExternalPower();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},*/

	/** to be removed -- Total power supplied to target Peer.
	 * /
	A_TOTAL_SUPPLIED_POWER {                  // 0x04
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalSuppliedLocalPower();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},*/

	/** Total Consumption Tasks completed by target Peer.
	 */
	A_TOTAL_COMPLETED_CONSUMPTION_TASKS {     // 0x05
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalCompletedConsumptionTasks();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total Supplying Tasks completed for target Peer.
	 */
	A_TOTAL_COMPLETED_SUPPLYING_TASKS {       // 0x06
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalCompletedSupplyingTasks();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total Consumption Tasks completed by target Peer.
	 */
	A_TOTAL_CANCELLED_CONSUMPTION_TASKS {     // 0x07
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalCancelledConsumptionTasks();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total Supplying Tasks cancelled for target Peer.
	 */
	A_TOTAL_CANCELLED_SUPPLYING_TASKS {       // 0x08
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getTotalCancelledSupplyingTasks();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Total Consumption Tasks completed by target Peer.
	 */
	A_RECENTLY_COMPLETED_CONSUMPTION_TASKS {  // 0x09
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getRecentlyCompletedConsumptionTasksCount();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Recent Supplying Tasks completed for target Peer.
	 */
	A_RECENTLY_COMPLETED_SUPPLYING_TASKS {    // 0x0A
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getRecentlyCompletedSupplyingTasksCount();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Recent Consumption Tasks cancelled by target Peer.
	 */
	A_RECENTLY_CANCELLED_CONSUMPTION_TASKS {  // 0x0B
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getRecentlyCancelledConsumptionTasksCount();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Recent Supplying Tasks cancelled for target Peer.
	 */
	A_RECENTLY_CANCELLED_SUPPLYING_TASKS {    // 0x0C
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double v = peer_bp.getRecentlyCancelledSupplyingTasksCount();
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Ratio of Consumption Tasks completed to accepted by target Peer.
	 */
	A_CONSUMPTION_SUCCESS_RATIO {             // 0x0D
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double co = peer_bp.getTotalCompletedConsumptionTasks();
			double ca = peer_bp.getTotalCancelledConsumptionTasks();
			double v = co / (co + ca);
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},

	/** Ratio of Supplying Tasks completed to accepted for target Peer.
	 */
	A_SUPPLYING_SUCCESS_RATIO {	              // 0x0E
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {

			double co = peer_bp.getTotalCompletedSupplyingTasks();
			double ca = peer_bp.getTotalCancelledSupplyingTasks();
			double v = co / (co + ca);
			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},
	
	/** Task nominal runtime.
	A_TASK_NOMINAL_RUNTIME {                  // 0x0F
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {
			
			double v = t.nominalRuntime();

			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	},
	*/

	/** Task cancellations count.
	 */
	A_TASK_CANCELLATIONS_COUNT {              // 0x10
		public double val(Task t,PeerBarteringProfile peer_bp)
			throws GridException {
			
			double v = t.getCancellationCount();

			if (v < 0.0) {
				throw new GridException("val(): illegal attribute value");
			}
			return v;

		}
	};

	/* A_TASK_INPUT_PARAMETERS = { params, jar, data id } --
	   would be worthwhile to investigate
	   see Kapadia et al.'s "Predictive Application-Performance Modeling
	   in a Computational Grid Environment" */

	/** Returns the value of interaction attribute
	 * for target Task and Peer.
	 * @param t target Task
	 * @param peer_bp targer Peer
	 * @exception GridException if a parameter is illegal
	 */
	public abstract double val(Task t,PeerBarteringProfile peer_bp)
		throws GridException;

	/** Counts the number of interaction attributes.
	 * @return number of interaction attributes
	 */
	public static int size() {
		
		return InteractionAttributes.values().length;
		
	}

}

