/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// PeerServiceFactory.java

package lbg.peer.service;

import lbg.*;
import lbg.common.exception.*;
import lbg.peer.*;

/**
 * @author Cyril Briquet
 */
public class PeerServiceFactory {

	public PeerServiceFactory() {
		
		this(false);
		
	}

	public PeerServiceFactory(boolean clone_simulated_transferred_objects) {
		
		this.clone_simulated_transferred_objects =
			clone_simulated_transferred_objects;
		
	}
	
	// ****************************************************************

	public PeerService createPeerService(Peer owner_peer) throws GridException {

		switch (LightweightBarteringGrid.getMode()) {
		case LIVE_MODE:
			return new LivePeerService(owner_peer);
		case SIM_MODE:
			return (this.clone_simulated_transferred_objects) ?
				new SimulatedWithCloningPeerService(owner_peer) :
				new SimulatedPeerService(owner_peer);
		default:
			throw new GridException("createPeerService(): "+
									"unsupported mode");
		}
		
	}

	// ****************************************************************

	private boolean clone_simulated_transferred_objects;

}

