/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedWithCloningPeerService.java

package lbg.peer.service;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.*;
import lbg.peer.core.qms.*;
import lbg.peer.core.qms.prequeue.*;
import lbg.task.*;

/** A partial reimplementation of SimulatedPeerService where incoming Tasks
 * are cloned before being passed to the overridden method.
 * @author Cyril Briquet
 */
public class SimulatedWithCloningPeerService extends SimulatedPeerService {

	public SimulatedWithCloningPeerService(Peer owner_peer) throws GridException {
	
		super(owner_peer);

	}

	public String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[SimulatedPeerService",
							   "[SimulatedWithCloningPeerService"));
		
		return sb.toString();

	}

	// ****************************************************************

	public ConsumptionTaskID computeSupplyingTask(String consumer_id,Task t)
		throws GridException {
		
		return super.computeSupplyingTask(consumer_id,cloneTask(t));
		
	}
	
	public void cancelSupplyingTaskOnLocalResource(String consumer_id,Task t)
		throws GridException {

		super.cancelSupplyingTaskOnLocalResource(consumer_id,cloneTask(t));

	}

	public void cancelLocalTaskOnSupplyingResource(String supplier_id,Task t)
		throws GridException {

		super.cancelLocalTaskOnSupplyingResource(supplier_id,cloneTask(t));
		
	}

	public void uploadBySupplyingCompletedTask(String supplier_id,Task t)
		throws GridException {
		
		super.uploadBySupplyingCompletedTask(supplier_id,cloneTask(t));

	}

	// ****************************************************************

	public void preemptLocalTaskOnLocalResource(Task t,byte[] logs)
		throws GridException {
		
		super.preemptLocalTaskOnLocalResource(cloneTask(t),logs);
	
	}

	public void preemptSupplyingTaskOnLocalResource(String consumer_id,
													Task t,byte[] logs)
		throws GridException {
		
		super.
			preemptSupplyingTaskOnLocalResource(consumer_id,cloneTask(t),logs);

	}

	public void uploadLocallyCompletedTask(Task t) throws GridException {
		
		super.uploadLocallyCompletedTask(cloneTask(t));

	}
	
	// ****************************************************************

	private Task cloneTask(Task t) {
	
		return (Task)t.clone();
		
	}

	// ****************************************************************

	static final long serialVersionUID = -5102548669650669861L;

}

