/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// TestPeerHandle.java

package lbg.peer.service;

import lbg.common.exception.*;
import lbg.common.math.*;
import lbg.peer.core.qms.*;
import lbg.peer.core.qms.prequeue.*;
import lbg.peer.workflow.*;
import lbg.resource.service.*;
import lbg.task.*;
import lbg.user.service.*;

/** Implementation of PeerHandles for testing purposes only.
 * @author Cyril Briquet
 */
public class TestPeerHandle implements
	ExternalPeerHandle, InternalPeerHandle, UserPeerHandle {

	/**
	 * @param id Peer id
	 */
	public TestPeerHandle(String id) throws GridException {

		if (id == null) {
			throw new GridException("TestPeerHandle(): illegal id");
		}
		
		this.id = id;
		this.hashcode = Integer.MIN_VALUE;
	
	}
	
	public String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[TestPeerHandle ");
		sb.append(this.id);
		sb.append("]");
		
		return sb.toString();

	}
	
	public int compareTo(PeerHandle other) {
	
		return this.id.compareToIgnoreCase(other.id());
		
	}

	@Override
	public boolean equals(Object obj) {
		
		if (obj instanceof PeerHandle == false) {
			return false;
		}
		
		return (this.compareTo((PeerHandle)obj) == 0);
		
	}

	@Override
	public int hashCode() {
	
		if (this.hashcode == Integer.MIN_VALUE) {
			this.hashcode = CommonMath.generateHashCode(this.id);
		}
		return this.hashcode;
	
	}
	
	// ****************************************************************

	public String id() {
		
		return this.id;
		
	}

	public String hostname() {
		
		return null;
		
	}
	
	// ****************************************************************

	public int peerPort() {
		
		return 0;
		
	}

	public void requestSupplying(String consumer_id,int tasks_count)
		throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public void grantConsumption(String supplier_id,int granted_count)
		throws GridException {
		
		throw new GridException("not implemented");
		
	}

	public ConsumptionTaskID computeSupplyingTask(String consumer_id,Task t)
		throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public void cancelSupplyingTaskOnLocalResource(String consumer_id,Task t)
		throws GridException {
		
		throw new GridException("not implemented");

	}

	public void cancelLocalTaskOnSupplyingResource(String supplier_id,Task t)
		throws GridException {
			
		throw new GridException("not implemented");
			
	}
			
	public void uploadBySupplyingCompletedTask(String supplier_id,Task t)
		throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public boolean isAlive() {
	
		return true;
		
	}

	// ****************************************************************

	public int resourcePort() {
		
		return 0;
		
	}

	public void addResource(ResourceHandle rh,int power) throws GridException {
		
		throw new GridException("not implemented");
		
	}
	
	public void removeResource(ResourceHandle rh) throws GridException {
		
		throw new GridException("not implemented");
		
	}

	public void preemptLocalTaskOnLocalResource(Task t,byte[] logs)
		throws GridException {
		
		throw new GridException("not implemented");

	}
	
	public void preemptSupplyingTaskOnLocalResource(String consumer_id,
													Task t,byte[] logs)
		throws GridException {
		
		throw new GridException("not implemented");

	}

	public void uploadLocallyCompletedTask(Task t)
		throws GridException {
		
		throw new GridException("not implemented");
		
	}

	// ****************************************************************

	public int userPort() {
		
		return 0;
		
	}

	public int submitJob(UserHandle uh,JobDescriptor jd) throws GridException {
		
		throw new GridException("not implemented");
		
	}

	public void cancelJob(int job_id) throws GridException {
		
		throw new GridException("not implemented");
		
	}

	public int queryJobStatus(int job_id) throws GridException {
		
		throw new GridException("not implemented");
		
	}

	// ****************************************************************
	
	static final long serialVersionUID = 3892512113398044387L;

	// ****************************************************************

	private String id;
	private int hashcode;

}

