/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// BarteringAccountantType.java

package lbg.peer.strategy.accounting;

import lbg.common.exception.*;
import lbg.peer.*;

/**
 * @author Cyril Briquet
 */
public enum BarteringAccountantType {
		
	NoEvalAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {

			return new NoEvalAccountant(peer);

		}

		public boolean isBarteringStrategy() { return false; }
	},
				
	OGPerfectAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {

			return new OGPerfectAccountant(peer);

		}

		public boolean isBarteringStrategy() { return true; }
	},
		
	OGTimeAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {
			
			return new OGTimeAccountant(peer);
				
		}

		public boolean isBarteringStrategy() { return true; }
	},
		
	OGRelativePowerAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {
			
			return new OGRelativePowerAccountant(peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	LBGTimeAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {
			
			return new LBGTimeAccountant(peer);
				
		}

		public boolean isBarteringStrategy() { return true; }
	},
		
	LBGRelativePowerAccountant {
		public BarteringAccountantPolicy createAccountant(Peer peer)
			throws GridException {
			
			return new LBGRelativePowerAccountant(peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	};
		
	// ****************************************************************

	public abstract BarteringAccountantPolicy createAccountant(Peer peer)
		throws GridException;

	public abstract boolean isBarteringStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_DEFAULT_ACCOUNTANT";
		
	}
	
	public static int size() {
		
		return BarteringAccountantType.values().length;
		
	}

	public static String[] getPolicyLabels() {
	
		String[] l = new String[BarteringAccountantType.values().length];
		int i = -1;
		for (BarteringAccountantType bat : BarteringAccountantType.values()) {
			l[++i] = bat.name();
		}
		return l;
		
	}
	
	// ****************************************************************

}

