/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NoEvalAccountant.java

package lbg.peer.strategy.accounting;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.task.*;

/**
 * <p>Implementation note:
 * this implementation does not rely on any information.
 * @author Cyril Briquet
 */
public class NoEvalAccountant implements BarteringAccountantPolicy {

	public NoEvalAccountant(Peer managed_peer)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NoEvalAccountant(): illegal Peer");
		}

		this.managed_peer = managed_peer;
		
	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[NoEvalAccountant ");
		sb.append(this.managed_peer.id());
		sb.append("]");
		
		return sb.toString();
		
	}
	
	/** BarteringAccountant implementation.
	 * @return 0.0
	 */
	public double evaluateSupplying(Task t,long xstart_time)
		throws GridException {

		if (t == null) {
			throw new GridException("evaluateSupplying(): illegal Task");
		}
		if (xstart_time < 0) {
			throw new GridException("evaluateSupplying(): "+
									"illegal execution start time");
		}
		
		return 0.0;
		
	}

	/** BarteringAccountant implementation.
	 * @return 0.0
	 */
	public double evaluateConsumption(Task t,long xstart_time)
		throws GridException {
		
		if (t == null) {
			throw new GridException("evaluateConsumption(): illegal Task");
		}
		if (xstart_time < 0) {
			throw new GridException("evaluateConsumption(): "+
									"illegal execution start time");
		}
		
		return 0.0;

	}

	private Peer managed_peer;

}

