/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ConsumptionNegotiationType.java

package lbg.peer.strategy.negotiation;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.strategy.negotiation.consumption.*;

/**
 * @author Cyril Briquet
 */
public enum ConsumptionNegotiationType {

	// ****************************************************************
	
	NoConsumptionNegotiation {
		public ConsumptionNegotiationPolicy
			createConsumptionNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new NoConsumptionNegotiation(managed_peer);
			
		}
		
		public boolean isBarteringStrategy() { return false; }
	},
	
	// ****************************************************************

	RandomConsumptionNegotiation {
		public ConsumptionNegotiationPolicy
			createConsumptionNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new RandomConsumptionNegotiation(managed_peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	};

	// ****************************************************************
	
	public abstract ConsumptionNegotiationPolicy
		createConsumptionNegotiationPolicy(Peer managed_peer)
		throws GridException;
	
	public abstract boolean isBarteringStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_NEGOTIATION_CONSUMPTION_POLICY";
		
	}
	
	public static int size() {
		
		return ConsumptionNegotiationType.values().length;
		
	}
	
	public static String[] getPolicyLabels() {
	
		String[] l = new String[ConsumptionNegotiationType.values().length];
		int i = -1;
		for (ConsumptionNegotiationType cnt :
				ConsumptionNegotiationType.values()) {
			l[++i] = cnt.name();
		}
		return l;
		
	}

	// ****************************************************************

}

