/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SupplyingNegotiationType.java

package lbg.peer.strategy.negotiation;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.strategy.negotiation.supplying.*;

/**
 * @author Cyril Briquet
 */
public enum SupplyingNegotiationType {

	// ****************************************************************

	NoSupplyingNegotiation {
		public SupplyingNegotiationPolicy
			createSupplyingNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new NoSupplyingNegotiation(managed_peer);
			
		}
	
		public boolean isBarteringStrategy() { return false; }
	},
	
	// ****************************************************************

	RandomSupplyingNegotiation {
		public SupplyingNegotiationPolicy
			createSupplyingNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new RandomSupplyingNegotiation(managed_peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	// ****************************************************************

	FavorsSupplyingNegotiation {
		public SupplyingNegotiationPolicy
			createSupplyingNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new FavorsSupplyingNegotiation(managed_peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	// ****************************************************************

/*
	ReliableSupplyingNegotiation {
		public SupplyingNegotiationPolicy
			createSupplyingNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new ReliableSupplyingNegotiation(managed_peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
*/
	
	// ****************************************************************

	UnlimitedSupplyingNegotiation {
		public SupplyingNegotiationPolicy
			createSupplyingNegotiationPolicy(Peer managed_peer)
			throws GridException {
			
			return new UnlimitedSupplyingNegotiation(managed_peer);
			
		}

		public boolean isBarteringStrategy() { return true; }
	};
	
	// ****************************************************************
	
	public abstract SupplyingNegotiationPolicy
		createSupplyingNegotiationPolicy(Peer managed_peer)
		throws GridException;

	public abstract boolean isBarteringStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_NEGOTIATION_SUPPLYING_POLICY";
		
	}
	
	public static int size() {
		
		return SupplyingNegotiationType.values().length;
		
	}
	
	public static String[] getPolicyLabels() {
	
		String[] l = new String[SupplyingNegotiationType.values().length];
		int i = -1;
		for (SupplyingNegotiationType snt : SupplyingNegotiationType.values()) {
			l[++i] = snt.name();
		}
		return l;
		
	}

	// ****************************************************************

}

