/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// CommonConsumptionNegotiation.java

package lbg.peer.strategy.negotiation.consumption;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.register.negotiation.*;
import lbg.peer.service.*;
import lbg.peer.strategy.negotiation.*;
import lbg.task.*;

/**	Reliability-ranked use of Consumption Grants.
 * @author Cyril Briquet
 */
public abstract class CommonConsumptionNegotiation
	implements ConsumptionNegotiationPolicy {

	public CommonConsumptionNegotiation(Peer managed_peer)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("CommonConsumptionNegotiation(): "+
									"illegal Peer");
		}
		
		this.managed_peer = managed_peer;
		
	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[CommonConsumptionNegotiation]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	/** ConsumptionNegotiationPolicy implementation.
	 */
	public synchronized void generateSupplyingRequests() throws GridException {

		int tasks_count = this.managed_peer.qms().countWaitingLocalTasks();
		if (tasks_count <= 0) {
			return;
		}

		for (ExternalPeerHandle peer_handle:
				this.managed_peer.searchEngine().search()) {

			if (peer_handle == null) { // search() may have null values, see doc
				break;
			}
			
			if (this.managed_peer.register().
					checkProfile(peer_handle.id()) == false) {
				continue; // avoid sending Supplying Requests to self
			}

			peer_handle.requestSupplying(this.managed_peer.id(),
										 tasks_count);

			this.managed_peer.register().getNeighborhoodNegotiationProfile().
			accountSentSupplyingRequests(peer_handle.id(),tasks_count);

		}

	}
	
	// ****************************************************************

	private final Peer managed_peer;

}

