/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NoSupplyingNegotiation.java

package lbg.peer.strategy.negotiation.supplying;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.register.negotiation.*;
import lbg.peer.strategy.negotiation.*;

/** No distribution of Consumption Grants.
 * @author Cyril Briquet
 */
public class NoSupplyingNegotiation implements SupplyingNegotiationPolicy {

	public NoSupplyingNegotiation(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NoSupplyingNegotiation(): illegal Peer");
		}

		this.managed_peer = managed_peer;

	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[NoSupplyingNegotiation]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized void evaluateSupplyingRequests()
		throws GridException {

		// Extract Peers which sent Supplying requests
		SupplyingRequestsContainer s_r =
			this.managed_peer.register().getNeighborhoodNegotiationProfile().
				getReceivedSupplyingRequests();
		if (s_r == null) return;
		
		// Do not send any Consumption Grant
		return;
		
	}

	// ****************************************************************

	private Peer managed_peer;

}

