/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// CommonRanking.java

package lbg.peer.strategy.ranking;

import lbg.common.exception.*;
import lbg.common.math.*;

/**
 * @author Cyril Briquet
 */
public abstract class CommonRanking implements Ranking {

	/** Ranking implementation.
	 */
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[CommonRanking]");
		
		sb.append("\n  ->  ");
		sb.append(getRankedPeerCount());
		sb.append(" ranked Peers out of ");
		sb.append(getPeerCount());
		sb.append(" (");
		sb.append(CommonMath.div_label_2dd(100*getRankedPeerRatio(),1));
		sb.append("% ranked)");
		sb.append("\n  ->  ranking = { ");
		int[] peers_ranking = peersRanking();
		for (int i = 0 ; i < peers_ranking.length ; i++) {
			sb.append("[");
			sb.append(peers_ranking[i]);
			sb.append("]");
			if (i < peers_ranking.length-1) sb.append(", ");
		}
		sb.append(" }  (each value is a contextual Peer index)");
		
		return sb.toString();
		
	}

	/** Ranking implementation.
	 */
	public abstract int getRankedPeerCount();
	
	/** Ranking implementation.
	 */
	public abstract int getUnrankedPeerCount();
	
	/** Ranking implementation.
	 */
	public abstract int[] peersRanking();
	
	/** Ranking implementation.
	 */
	public float getRankedPeerRatio() {
		 
		int ranked_peers = getRankedPeerCount();
		int total_peers  = ranked_peers + getUnrankedPeerCount();
		return ((float)ranked_peers)/((float)total_peers);
		 
	}
	
	/** Ranking implementation.
	 */
	public float getUnrankedPeerRatio() {
		 
		int unranked_peers = getUnrankedPeerCount();
		int total_peers  = getRankedPeerCount() + unranked_peers;
		return ((float)unranked_peers)/((float)total_peers);
		 
	}

	/** Ranking implementation.
	 */
	public float getBlacklistedPeerRatio() {
		 
		return ((float)getBlacklistedPeerCount())/((float)getPeerCount());
		 
	}

	/** Ranking implementation.
	 */
	public int getPeerCount() {
		
		return getRankedPeerCount()+getUnrankedPeerCount();
		
	}

}

