/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// MergedRanking.java

package lbg.peer.strategy.ranking;

import lbg.common.*;
import lbg.common.exception.*;
import lbg.common.io.*;

/** MergedRanking stores the ranking resulting from the merging
 * of multiple rankings (some of which may even be merged rankings themselves)
 * by the Rankings class.
 * @author Cyril Briquet
 */
public class MergedRanking extends CommonRanking {
	
	public MergedRanking(int[] peers_ranking) throws GridException {
		
		if ((peers_ranking == (int[])null) || (peers_ranking.length < 1)) {
			throw new GridException("MergedRanking(): illegal ranking");
		}
		
		this.peers_ranking  = peers_ranking;
		this.ranked_peers   = peers_ranking.length;
		this.unranked_peers = 0;
		this.blacklisted_peers = 0;
		
	}

	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[CommonRanking]",
							   "[MergedRanking]"));

		return sb.toString();
		
	}

	// ****************************************************************

	/** Ranking implementation.
	 * @return Peers ranking, or null if no Peers can be ranked
	 */
	public int[] peersRanking() {
		
		return this.peers_ranking;
		
	}

	/** Ranking implementation.
	 */
	public int getRankedPeerCount() {
		
		return this.ranked_peers;
		
	}
	
	/** Ranking implementation.
	 */
	public int getUnrankedPeerCount() {
		
		return this.unranked_peers;
		
	}

	/** Ranking implementation.
	 */
	public int getBlacklistedPeerCount() {
		
		return this.blacklisted_peers;
		
	}
	
	// ****************************************************************

	private final int[] peers_ranking;
	private final int ranked_peers;
	private final int unranked_peers;
	private final int blacklisted_peers;

}

