/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ConsumptionSchedulingType.java

package lbg.peer.strategy.scheduling;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.negotiator.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.consumption.*;

/**
 * @author Cyril Briquet
 */
public enum ConsumptionSchedulingType {

	// ****************************************************************

	NoConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new NoConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return false; }
	},
	
	// ****************************************************************

	RandomConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new RandomConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	DataConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new DataConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	AdaptiveMC4ConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return
				new AdaptiveMC4ConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	AdaptiveTCoRConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return
				new AdaptiveTCoRConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	ConservativeTimeStrideConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new ConservativeTimeStrideConsumptionScheduling(managed_peer,
																   scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	// ****************************************************************
	
	FavorsConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new FavorsConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	// ****************************************************************

	GrantsConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new GrantsConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},
	
	// ****************************************************************

	MC4ConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new MC4ConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	MCoSConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new MCoSConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	MTBCConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new MTBCConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	MTTCConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new MTTCConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	PerformanceConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new PerformanceConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	ReliableConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new ReliableConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	},

	// ****************************************************************

	TCaRConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new TCaRConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	};

	// ****************************************************************

	/*
	TCoRConsumptionScheduling {
		public ConsumptionSchedulingPolicy
			createConsumptionSchedulingPolicy(Peer managed_peer,
											  Scheduler scheduler)
			throws GridException {
			
			return new TCoRConsumptionScheduling(managed_peer,scheduler);
			
		}

		public boolean isBarteringStrategy() { return true; }
	};
	*/

	// ****************************************************************
	
	public abstract ConsumptionSchedulingPolicy
		createConsumptionSchedulingPolicy(Peer managed_peer,
										  Scheduler scheduler)
		throws GridException;


	public abstract boolean isBarteringStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_SCHEDULING_CONSUMPTION_POLICY";
		
	}
	
	public static int size() {
		
		return ConsumptionSchedulingType.values().length;
		
	}

	public static String[] getPolicyLabels() {
	
		String[] l = new String[ConsumptionSchedulingType.values().length];
		int i = -1;
		for (ConsumptionSchedulingType cst :
				ConsumptionSchedulingType.values()) {
			l[++i] = cst.name();
		}
		return l;
		
	}
	
	// ****************************************************************

}

