/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LocalSchedulingType.java

package lbg.peer.strategy.scheduling;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.local.*;

/**
 * @author Cyril Briquet
 */
public enum LocalSchedulingType {

	// ****************************************************************

	NonpreemptiveLocalScheduling {
		public LocalSchedulingPolicy
			createLocalSchedulingPolicy(Peer managed_peer,Scheduler scheduler)
			throws GridException {
			
			return new NonpreemptiveLocalScheduling(managed_peer,scheduler);
			
		}

		public boolean isPreemptionStrategy() { return false; }
	},
	
	// ****************************************************************

	PreemptiveLocalScheduling {
		public LocalSchedulingPolicy
			createLocalSchedulingPolicy(Peer managed_peer,Scheduler scheduler)
			throws GridException {
			
			return new PreemptiveLocalScheduling(managed_peer,scheduler);
			
		}
		
		public boolean isPreemptionStrategy() { return true; }

	};
	
	// ****************************************************************

	public abstract LocalSchedulingPolicy
		createLocalSchedulingPolicy(Peer managed_peer,Scheduler scheduler)
		throws GridException;
		
	public abstract boolean isPreemptionStrategy();
	
	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_SCHEDULING_LOCAL_POLICY";
		
	}

	public static int size() {
		
		return LocalSchedulingType.values().length;
		
	}

	public static String[] getPolicyLabels() {
	
		String[] l = new String[LocalSchedulingType.values().length];
		int i = -1;
		for (LocalSchedulingType lst : LocalSchedulingType.values()) {
			l[++i] = lst.name();
		}
		return l;
		
	}
	
	// ****************************************************************

}

