/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SupplyingRunningPreemptionType.java

package lbg.peer.strategy.scheduling;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.preemption.*;

/**
 * @author Cyril Briquet
 */
public enum SupplyingRunningPreemptionType {

	// ****************************************************************
	
	NoPreemption {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new NoPreemption(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return false; }
	},
	
	// ****************************************************************
	
	LimitedPreemption {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new LimitedPreemption(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************
	
	FullPreemption {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new FullPreemption(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************
	
	LimitedCancellation {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new LimitedCancellation(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************
	
	FullCancellation {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new FullCancellation(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},

	
	// ****************************************************************
	
	AdaptivePreemption {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new AdaptivePreemption(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	AdaptivePreemptionGrace1 {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new AdaptivePreemptionGrace1(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},

	AdaptivePreemptionGrace2 {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new AdaptivePreemptionGrace2(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},

	AdaptivePreemptionGrace5 {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new AdaptivePreemptionGrace5(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},

	AdaptivePreemptionGrace10 {
		public SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
			throws GridException {
		
			return new AdaptivePreemptionGrace10(managed_peer,scheduler);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	};
	
	// ****************************************************************

	public abstract SupplyingRunningPreemptionPolicy
			createSupplyingRunningPreemptionPolicy(Peer managed_peer,
												   Scheduler scheduler)
		throws GridException;

	public abstract boolean isPreemptionStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_PREEMPTION_SUPPLYING_RUNNING_POLICY";
		
	}
	
	public static int size() {
		
		return SupplyingRunningPreemptionType.values().length;
		
	}

	public static String[] getPolicyLabels() {
	
		String[] l = new String[SupplyingRunningPreemptionType.values().length];
		int i = -1;
		for (SupplyingRunningPreemptionType srpt :
				SupplyingRunningPreemptionType.values()) {
			l[++i] = srpt.name();
		}
		return l;
		
	}

	// ****************************************************************

}

