/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SupplyingWaitingPreemptionType.java

package lbg.peer.strategy.scheduling;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.preemption.*;

/**
 * @author Cyril Briquet
 */
public enum SupplyingWaitingPreemptionType {

	// ****************************************************************
	
	NoPreemption {
		public SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
			throws GridException {
			
			return new NoPreemption(managed_peer);
		
		}

		public boolean isPreemptionStrategy() { return false; }
	},
	
	// ****************************************************************

	NoWaitingPreemption {
		public SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
			throws GridException {
		
			return new NoWaitingPreemption(managed_peer);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************

	FavorsWaitingPreemption {
		public SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
			throws GridException {
		
			return new FavorsWaitingPreemption(managed_peer);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************

	FIFOWaitingPreemption {
		public SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
			throws GridException {
		
			return new FIFOWaitingPreemption(managed_peer);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	},
	
	// ****************************************************************

	FullWaitingPreemption {
		public SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
			throws GridException {
		
			return new FullWaitingPreemption(managed_peer);
		
		}

		public boolean isPreemptionStrategy() { return true; }
	};
	
	// ****************************************************************

	public abstract SupplyingWaitingPreemptionPolicy
			createSupplyingWaitingPreemptionPolicy(Peer managed_peer)
		throws GridException;

	public abstract boolean isPreemptionStrategy();

	// ****************************************************************

	public static final String getPDPLabel() {
	
		return "PEER_PREEMPTION_SUPPLYING_WAITING_POLICY";
		
	}
	
	public static int size() {
		
		return SupplyingWaitingPreemptionType.values().length;
		
	}

	public static String[] getPolicyLabels() {
	
		String[] l = new String[SupplyingWaitingPreemptionType.values().length];
		int i = -1;
		for (SupplyingWaitingPreemptionType swpt :
				SupplyingWaitingPreemptionType.values()) {
			l[++i] = swpt.name();
		}
		return l;
		
	}

	// ****************************************************************

}

