/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// FavorsConsumptionScheduling.java

package lbg.peer.strategy.scheduling.consumption;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.config.*;
import lbg.peer.core.qms.*;
import lbg.peer.core.qms.queue.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.register.learning.consumption.*;
import lbg.peer.register.negotiation.*;
import lbg.peer.strategy.scheduling.*;
import lbg.peer.strategy.ranking.*;

/**	Reliability-ranked use of Consumption Grants.
 * @author Cyril Briquet
 */
public class FavorsConsumptionScheduling
	extends CommonConsumptionScheduling
	implements ConsumptionSchedulingPolicy {

	public FavorsConsumptionScheduling(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		super(managed_peer,scheduler);

		if (managed_peer == null) {
			throw new GridException("FavorsConsumptionScheduling(): "+
									"illegal Peer");
		}

		this.managed_peer = managed_peer;
		this.lqc = new LocalQueueCursor();
		
	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[FavorsConsumptionScheduling]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	/** Rank Suppliers.
	 * @param c_g collected Consumption Grants container
	 * @param rc target Task container
	 * @return Suppliers Ranking
	 * @exception GridException if a problem occured while ranking Suppliers
	 */
	protected synchronized Ranking
		rankSuppliers(ConsumptionGrantsContainer c_g,RequestContainer rc)
		throws GridException {
		
		if (c_g == null) {
			throw new GridException("rankSuppliers(): illegal Consumption "+
									" Grants container");
		}
		if (rc == null) {
			throw new GridException("rankSuppliers(): illegal Task container");
		}
		
		JobConsumptionOutcomeTracker jcot =
			rc.getJobConsumptionOutcomeTracker();
		PeerStrategyConfiguration strategy_config =
			this.managed_peer.strategyConfig();
		Ranking ranking =
			new FavorsConsumptionRanking(c_g,jcot,
										 strategy_config.
										 DO_CONSUMPTION_BLACKLIST());
										 //strategy_config.
										 //CONSUMPTION_BLACKLIST_PROBA()););
		
		return ranking;
		
	}
	
	/** Local Queue Cursor accessor.
	 * @return Local Queue Cursor, or null if none has been defined
	 */
	protected synchronized LocalQueueCursor getLocalQueueCursor() {
		
		return this.lqc;
		
	}

	// ****************************************************************

	private final Peer managed_peer;
	private final LocalQueueCursor lqc;

}

