/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NoConsumptionScheduling.java

package lbg.peer.strategy.scheduling.consumption;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.*;

/** No Consumption Scheduling.
 * @author Cyril Briquet
 */
public class NoConsumptionScheduling implements ConsumptionSchedulingPolicy {

	public NoConsumptionScheduling(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NoConsumptionScheduling(): "+
									"illegal Peer");
		}
		if (scheduler == null) {
			throw new GridException("NoConsumptionScheduling(): "+
									"illegal Scheduler");
		}
		
	}

	/** ConsumptionSchedulingPolicy implementation.
	 * @return zero, as no Consumption Task has been scheduled
	 */
	public synchronized int scheduleConsumptionTasks()
		throws GridException {
		
		return 0;
		
	}

}

