/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// CommonSupplyingFiltering.java

package lbg.peer.strategy.scheduling.filtering;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.strategy.scheduling.*;
import lbg.task.Task;

/** Common Supplying filtering.
 * @author Cyril Briquet
 */
public abstract class CommonSupplyingFiltering
	implements SupplyingFilteringPolicy {

	public CommonSupplyingFiltering(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("CommonSupplyingFiltering(): "+
									"illegal Peer");
		}
		
		this.managed_peer = managed_peer;
		
	}

	/** SupplyingFilteringPolicy implementation.
	 */
	public abstract boolean filterOutSupplyingTask(Task t) throws GridException;
	
	/** Checks if Supplying queue filtering threshold is exceeded.
	 * @return true if Supplying queue filtering threshold exceeded
	 * @exception GridException in case of corrupted data
	 */
	boolean isThresholdExceeded() throws GridException {
		
		boolean retval;
		
		if (this.managed_peer.rms().countTotalResources() < 1) {
			retval = true; // no Resource... filter out
		}
		else {
			int outstanding_tasks =
				// ... without considering Consumption Tasks
				this.managed_peer.qms().countWaitingLocalTasks()
				+this.managed_peer.qms().countWaitingSupplyingTasks()
				-this.managed_peer.rms().countIdleResources();
			
			if (outstanding_tasks <= 0) {
				retval = false;  // enough Resources... supply
			}
			else {
				// let's cmp with queue length
				retval = (outstanding_tasks >=
						  this.managed_peer.strategyConfig().
						  PEER_Q_FILTERING_THRESHOLD());
			}
		}

		return retval;
		
	}
	
	private final Peer managed_peer;

}

