/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// UnlimitedSupplyingFiltering.java

package lbg.peer.strategy.scheduling.filtering;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.strategy.scheduling.*;
import lbg.task.Task;

/** Unlimited Supplying filtering.
 * @author Cyril Briquet
 */
public class UnlimitedSupplyingFiltering extends CommonSupplyingFiltering
	implements SupplyingFilteringPolicy {

	public UnlimitedSupplyingFiltering(Peer managed_peer) throws GridException {
	
		super(managed_peer);
		
		if (managed_peer == null) {
			throw new GridException("UnlimitedSupplyingFiltering(): "+
									"illegal Peer");
		}
		
		this.managed_peer = managed_peer;
		
	}

	/** SupplyingFilteringPolicy implementation.
	 */
	public synchronized boolean filterOutSupplyingTask(Task t)
		throws GridException {

		if (t == null) {
			throw new GridException("filterOutSupplyingTask(): "+
									"illegal Supplying Task");
		}

		return false;
		
	}
	
	private final Peer managed_peer;

}

