/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NonpreemptiveLocalScheduling.java

package lbg.peer.strategy.scheduling.local;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.qms.*;
import static lbg.peer.core.rms.ResourceState.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.*;
import lbg.resource.service.*;
import lbg.task.*;

/** Nonpreemptive Local Scheduling.
 * @author Cyril Briquet
 */
public class NonpreemptiveLocalScheduling implements LocalSchedulingPolicy {

	public NonpreemptiveLocalScheduling(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NonpreemptiveLocalScheduling(): "+
									"illegal Peer");
		}
		if (scheduler == null) {
			throw new GridException("NonpreemptiveLocalScheduling(): "+
									"illegal Scheduler");
		}

		this.managed_peer = managed_peer;
		this.scheduler = scheduler;
	
	}

	// ****************************************************************

	/** LocalSchedulingPolicy implementation.
	 */
	public synchronized void scheduleLocalTasks() throws GridException {
		
		while (this.managed_peer.qms().hasWaitingLocalTasks() &&
			   this.managed_peer.rms().hasIdleResource()) {

			Task t = selectLocalTask();
			
			ResourceHandle rh = this.managed_peer.rms().locateResource(IDLE,t);
			if (rh == null) {
				// with NoPreemption policy,
				// or if data is too large to store on any Resource
				this.managed_peer.qms().requeueUnqueuedLocalTask(t);
				return;
			}
			
			if (this.managed_peer.xms().runLocalTaskOnLocalResource(t,rh) ==
				false) {
				this.managed_peer.qms().requeueUnqueuedLocalTask(t);
				return;
			}

			this.scheduler.accountSchedulerLocalDecision();
		}
		
	}

	// ****************************************************************

	private Task selectLocalTask() throws GridException {
		
		RequestContainer rc = this.managed_peer.qms().
			scheduleFirstLocalTask(this.managed_peer.basicConfig().
								   SCHEDULE_HEAD_JOB_ONLY);
		if (rc == null) {
			throw new GridException("selectLocalTask(): "+
									"corrupted QueueManager data");
		}
		return rc.getTask();
		
	}
	
	// ****************************************************************

	private Peer managed_peer;
	private Scheduler scheduler;

}

