/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// FavorsWaitingPreemption.java

package lbg.peer.strategy.scheduling.preemption;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.strategy.scheduling.*;

/** NoF-based selection of waiting Supplying Tasks to dequeue.
 * @author Cyril Briquet
 */
public class FavorsWaitingPreemption
	implements SupplyingWaitingPreemptionPolicy {

	public FavorsWaitingPreemption(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("FavorsWaitingPreemption(): illegal Peer");
		}

		this.managed_peer = managed_peer;
	
	}

	// ****************************************************************

	/** SupplyingWaitingPreemptionPolicy implementation.
	 */
	public synchronized void preemptWaitingSupplyingTasks()
		throws GridException {
		
		int preempt_count =
			this.managed_peer.qms().countWaitingSupplyingTasks() -
			this.managed_peer.strategyConfig().
			PEER_Q_FILTERING_THRESHOLD();
		if (preempt_count > 0) {
			this.managed_peer.qms().
				dequeueWorstRankedWaitingSupplyingTasks(true,preempt_count);
		}
		
	}

	// ****************************************************************

	private final Peer managed_peer;

}

