/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// FullPreemption.java

package lbg.peer.strategy.scheduling.preemption;

import lbg.common.exception.*;
import static lbg.common.io.CommonStringHandling.*;
import lbg.peer.*;
import static lbg.peer.core.rms.ResourceState.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.*;
import lbg.resource.service.*;
import lbg.task.*;

/** Fully preemptive Preemption (all Supplying Tasks are requeued).
 * @author Cyril Briquet
 */
public class FullPreemption implements SupplyingRunningPreemptionPolicy {

	public FullPreemption(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("FullPreemption(): illegal Peer");
		}
		if (scheduler == null) {
			throw new GridException("FullPreemption(): illegal Scheduler");
		}

		this.managed_peer = managed_peer;
		this.scheduler = scheduler;
	
	}

	// ****************************************************************

	/** SupplyingRunningPreemptionPolicy implementation.
	 */
	public synchronized void preemptLocalResources(Task prioritary_task)
		throws GridException {

		while (this.managed_peer.rms().hasBusySupplyingResource()) {
			// Locate another Busy Supplying Resource
			ResourceHandle rh =
				this.managed_peer.rms().
					locateResource(BUSY_SUPPLYING,prioritary_task);
			if (rh == null) break;

			Task t = this.managed_peer.rms().getRunningTask(rh);

			// Actually preempt the Task
			this.managed_peer.xms().
				preemptSupplyingTaskOnLocalResource(t,DUMMY_LOG);

			this.scheduler.accountSchedulerPreemptionDecision();
		}
		
	}

	// ****************************************************************

	private Peer managed_peer;
	private Scheduler scheduler;

}

