/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// NoPreemption.java

package lbg.peer.strategy.scheduling.preemption;

import lbg.common.exception.*;
import lbg.peer.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.*;
import lbg.task.*;

/** No Preemption.
 * @author Cyril Briquet
 */
public class NoPreemption implements
	SupplyingRunningPreemptionPolicy, SupplyingWaitingPreemptionPolicy {

	public NoPreemption(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NoPreemption(): illegal Peer");
		}
		if (scheduler == null) {
			throw new GridException("NoPreemption(): illegal Scheduler");
		}
		
	}

	public NoPreemption(Peer managed_peer) throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("NoPreemption(): illegal Peer");
		}
		
	}

	/** SupplyingRunningPreemptionPolicy implementation.
	 */
	public synchronized void preemptLocalResources(Task prioritary_task)
		throws GridException {
		
		return;
		
	}

	/** SupplyingWaitingPreemptionPolicy implementation.
	 */
	public synchronized void preemptWaitingSupplyingTasks()
		throws GridException {
		
		return;
		
	}

}

