/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// FIFOSupplyingScheduling.java

package lbg.peer.strategy.scheduling.supplying;

import lbg.common.exception.*;
import lbg.peer.*;
import static lbg.peer.core.rms.ResourceState.*;
import lbg.peer.core.qms.*;
import lbg.peer.core.scheduler.*;
import lbg.peer.strategy.scheduling.*;
import lbg.resource.service.*;
import lbg.task.*;

/** FIFO-ranked Suppling Scheduling.
 * @author Cyril Briquet
 */
public class FIFOSupplyingScheduling implements SupplyingSchedulingPolicy {

	public FIFOSupplyingScheduling(Peer managed_peer,Scheduler scheduler)
		throws GridException {
	
		if (managed_peer == null) {
			throw new GridException("FIFOSupplyingScheduling(): "+
									"illegal Peer");
		}
		if (scheduler == null) {
			throw new GridException("FIFOSupplyingScheduling(): "+
									"illegal Scheduler");
		}

		this.managed_peer = managed_peer;
		this.scheduler = scheduler;
	
	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[FIFOSupplyingScheduling]");
		
		return sb.toString();
		
	}

	// ****************************************************************
	
	/** SupplyingSchedulingPolicy implementation.
	 */
	public synchronized void scheduleSupplyingTasks()
		throws GridException {

		while (this.managed_peer.qms().hasWaitingSupplyingTasks() &&
			   this.managed_peer.rms().hasIdleResource()) {

			// Schedule Supplying Task following a FIFO policy
			RequestContainer rc =
				this.managed_peer.qms().scheduleFirstSupplyingTask();
			if (rc == null) {
				throw new GridException("scheduleSupplyingTasks(): "+
										"corrupted QueueManager data");
			}
			Task t = rc.getTask();
		
			ResourceHandle rh =	this.managed_peer.rms().locateResource(IDLE,t);
			if (rh == null) {
				this.managed_peer.qms().requeueUnqueuedSupplyingTask(t);
				return;
			}
			
			if (this.managed_peer.xms().runSupplyingTaskOnLocalResource(t,rh) ==
				false) {
				this.managed_peer.qms().requeueUnqueuedSupplyingTask(t);
				return;
			}
			
			this.scheduler.accountSchedulerSupplyingDecision();
		}
		
	}

	// ****************************************************************

	private Peer managed_peer;
	private Scheduler scheduler;

}

