/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// PeerWebServer.java

package lbg.peer.web;

import lbg.common.*;
import lbg.common.exception.*;
import static lbg.common.io.CommonStringHandling.getStackTrace;
import lbg.peer.*;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.logging.Logger;

/**
 * @author Cyril Briquet
 */
public class PeerWebServer implements Runnable {
	
	public PeerWebServer(Peer p) throws GridException {
		
		if (p == null) {
			throw new GridException("PeerWebServer(): illegal Peer");
		}
		
		this.p = p;
		this.thread_pool = new ThreadPool(this,1,true,true,"WebServer-daemon");
		try {
			this.ss = new ServerSocket(this.p.netConfig().webPort());
		}
		catch (IOException e) {
			throw new GridException(e);
		}
		this.q = new LinkedBlockingQueue<Socket>();
		this.status_provider = new PeerWebStatusProvider(this.p,this.q);
		
	}

	public synchronized String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[PeerWebServer]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	// Runnable implementation
	public void run() {
		
		for ( ; ; ) { // server loop
			try {
				Socket s = this.ss.accept();
				this.q.put(s);
			}
			catch (Throwable thr) {
				this.p.logger().info("PeerWebServer: "+getStackTrace(thr));
			}
		}
		
	}
	
	public void startService() throws GridException {
		
		this.status_provider.startService();
		this.thread_pool.startService();
		
	}

	// ****************************************************************

	private final Peer p;
	private final ThreadPool thread_pool;
	private final ServerSocket ss;
	private final LinkedBlockingQueue<Socket> q;
	private final PeerWebStatusProvider status_provider;

}

