/*
 * Copyright 2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Edits for Lightweight Bartering Grid by Xavier Dalem
 *
 */

// RestrictedRequestHandler.java

package lbg.protocol.data;

import java.util.logging.Logger;

/**
 * This is a generic request handler, tweaked to restrict commands.
 * It delegates the request to appropriate method in subclass.
 *
 * @author <a href="mailto:rana_b@yahoo.com">Rana Bhattacharyya</a>
 * @author Xavier Dalem
 */
class RestrictedRequestHandler extends org.apache.ftpserver.RequestHandler {
	private static final Logger LOGGER = Logger.getLogger("lbg.data.ftp");
	
    /**
     * Constructor - set the control socket.
     */
    public RestrictedRequestHandler(org.apache.ftpserver.interfaces.IFtpConfig fconfig, java.net.Socket controlSocket) throws java.io.IOException {
		super(fconfig, controlSocket);
		LOGGER.finest("FTP server: handling requests from " + controlSocket);
    }
    
    /**
     * Check user permission to execute ftp command. 
     */
    protected boolean hasPermission() {
    	String cmd = getRequest().getCommand();
    	
    	if(cmd == null) {
    		return false;
    	}
    	
    	return (getRequest().isLoggedIn() && (
    			cmd.equals("RETR") ||
    			cmd.equals("TYPE") ||
    			cmd.equals("PORT"))
    			) ||
    		cmd.equals("USER") || 
    		cmd.equals("PASS") ||
    		//cmd.equals("AUTH") ||
    		//cmd.equals("HELP") ||
    		//cmd.equals("SYST") ||
    		cmd.equals("QUIT");
    }
}

