/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// UnlimitedCache.java

package lbg.protocol.data;

/** This class implements an unbounded cache.
 * 
 * @author Xavier Dalem
 *
 * @param <K> The type of the entries
 */
public class UnlimitedCache<K extends Comparable<? extends K>> extends Cache<K> {
	
	public UnlimitedCache() {
		super();
	}

	@Override
	/** @inheritDocs */
	public Metadata<K> add(K entry, Metadata<K> meta) {
		if (entry == null)
			throw new NullPointerException("null entry");
		if (meta == null)
			throw new NullPointerException("null metadata");
		
		if (! entries.containsKey(entry))
			entries.put(entry, meta);
		
		return null;
	}

	@Override
	public boolean canAdd(Metadata<K>[] entries, boolean mindVeto) {
		return true;
	}

	@Override
	public boolean isFull() {
		return false;
	}

	@Override
	public K selectForRemoval() {
		return null;
	}
	
	/** Returns a String representation of this cache */
	public String toString() {
		return "Unlimited cache (" + size() + " entries known)";
	}

}
