/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// HandleDownloader.java

package lbg.protocol.rpc;

import lbg.common.exception.*;
import lbg.common.net.*;
import lbg.peer.service.*;
import lbg.searchengine.service.*;

/**
 * @author Cyril Briquet
 */
public abstract class HandleDownloader {

	/** Downloads a LivePeerHandle from target Peer.
	 * @param hostname target Peer hostname
	 * @param port target Peer port
	 * @return downloaded LivePeerHandle
	 * @exception GridException if a parameter is illegal,
	 * or if no LivePeerHandle could be downloaded
	 */
	 public static LivePeerHandle downloadPeerHandle(String hostname,int port)
	 	throws GridException {
		
		if (hostname == null) {
			throw new GridException("downloadPeerHandle(): "+
									"illegal hostname");
		}
		if (CommonNetHandling.isValidPort(port) == false) {
			throw new GridException("downloadPeerHandle(): "+
									"illegal port");
		}

		LivePeerHandle ph = null;

		try {
			ph = RemoteCall.getPeerHandle(hostname,port);
		}
		catch (GridException e) {
			throw new GridException("downloadPeerHandle(): "+
									"could not connect to Peer "+
									hostname+":"+port,e);
		}
		
		return ph;
		
	}
	
	/** Downloads a LiveSearchEngineHandle from target Peer.
	 * @param hostname target Search engine hostname
	 * @param port target Search engine port
	 * @return downloaded LiveSearchEngineHandle
	 * @exception GridException if a parameter is illegal,
	 * or if no LiveSearchEngineHandle could be downloaded
	 */
	 public static LiveSearchEngineHandle
	 	downloadSearchEngineHandle(String hostname,int port)
	 	throws GridException {
		
		if (hostname == null) {
			throw new GridException("LiveSearchEngineHandle(): "+
									"illegal hostname");
		}
		if (CommonNetHandling.isValidPort(port) == false) {
			throw new GridException("LiveSearchEngineHandle(): "+
									"illegal port");
		}

		LiveSearchEngineHandle seh = null;

		try {
			seh = RemoteCall.getSearchEngineHandle(hostname,port);
		}
		catch (GridException e) {
			throw new GridException("LiveSearchEngineHandle(): "+
									"could not connect to Search engine "+
									hostname+":"+port,e);
		}
		
		return seh;
		
	}

}

