/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ResourceBasicConfiguration.java

package lbg.resource.config;

import lbg.*;
import static lbg.VirtualizationLevel.*;
import lbg.common.exception.*;
import lbg.common.io.*;
import static lbg.common.io.CommonStringHandling.*;
import java.util.Properties;

/** Resource basic configuration
 * @author Cyril Briquet
 */
public class ResourceBasicConfiguration {

	/** Creates a new ResourceBasicConfiguration.
	 */
	public ResourceBasicConfiguration(Properties props) throws GridException {
		
		if (props == null) {
			throw new GridException("ResourceBasicConfiguration(): "+
									"illegal Properties");
		}
		
		this.RESOURCE_ID = loadProperty("RESOURCE_ID",props);
		this.RESOURCE_POWER = loadInt(loadProperty("RESOURCE_POWER",props));

		// ****************
		
		checkProperties();

	}
	
	/** Creates a new ResourceBasicConfiguration (legal in SIM_MODE only).
	 */
	public ResourceBasicConfiguration(String resource_id,int resource_power)
		throws GridException {
		
		if (LightweightBarteringGrid.getMode() != SIM_MODE) {
			throw new GridException("ResourceBasicConfiguration(): "+
									"wrong constructor");
		}

		if (resource_id == null) {
			throw new GridException("ResourceBasicConfiguration(): "+
									"illegal Resource id");
		}
		if (resource_power < 1) {
			throw new GridException("ResourceBasicConfiguration(): "+
									"illegal Resource power");
		}
		
		this.RESOURCE_ID = resource_id;
		this.RESOURCE_POWER = resource_power;

		// ****************
		
		checkProperties();

	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[ResourceBasicConfiguration]");
		sb.append(format(true));
		
		return sb.toString();
		
	}
	
	/** Outputs the ResourceBasicConfiguration,
	 * formatted either as a property file or as a log file.
	 * @param log_format true to format ResourceBasicConfiguration as a log file
	 * @return formatted ResourceBasicConfiguration
	 */
	public String format(boolean log_format) {
		
		StringBuilder sb = new StringBuilder();

		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("RESOURCE_ID = ");
		sb.append(this.RESOURCE_ID);
		
		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("RESOURCE_POWER = ");
		sb.append(this.RESOURCE_POWER);
		
		return sb.toString();

	}
	
	// ****************************************************************

	public String RESOURCE_ID() {
	
		return this.RESOURCE_ID;
		
	}

	public int RESOURCE_POWER() {
	
		return this.RESOURCE_POWER;
		
	}

	// ****************************************************************

	private void checkProperties() throws GridException {

		if ((this.RESOURCE_ID == null) ||
			(this.RESOURCE_ID.length() < 1)) {
			throw new GridException("checkProperties(): "+
									"illegal Resource id");
		}
		
		if (this.RESOURCE_POWER < 1) {
			throw new GridException("checkProperties(): "+
									"illegal Resource power");
		}

	}

	// ****************************************************************

	private String RESOURCE_ID;
	private int RESOURCE_POWER;
	
}

