/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ResourceReliabilityConfiguration.java

package lbg.resource.config;

import lbg.*;
import static lbg.VirtualizationLevel.*;
import lbg.common.exception.*;

/** Resource reliability configuration 
 * (currently intended for use in SIM_MODE only).
 * @author Cyril Briquet
 */
public class ResourceReliabilityConfiguration {

	/** Creates a new ResourceReliabilityConfiguration (legal in SIM_MODE only).
	 * @param mtbf Mean Time Between Failures (always >= 0, with 0 indicating
	 * that the Resource is perfectly reliable). 
	 * @exception GridException if a parameter is illegal
	 */
	public ResourceReliabilityConfiguration(int mtbf)
		throws GridException {
		
		if (LightweightBarteringGrid.getMode() != SIM_MODE) {
			throw new GridException("ResourceReliabilityConfiguration(): "+
									"wrong constructor");
		}

		if (mtbf < 0) {
			throw new GridException("ResourceReliabilityConfiguration(): "+
									"illegal mean time between failures");
		}
		
		this.MTBF = mtbf;

		// ****************
		
		checkProperties();

	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[ResourceReliabilityConfiguration]");
		sb.append(format(true));
		
		return sb.toString();
		
	}
	
	/** Outputs the ResourceReliabilityConfiguration,
	 * formatted either as a property file or as a log file.
	 * @param log_format true to format ResourceReliabilityConfiguration as a log file
	 * @return formatted ResourceReliabilityConfiguration
	 */
	public String format(boolean log_format) {
		
		StringBuilder sb = new StringBuilder();

		sb.append("\n");
		if (log_format) sb.append("  ->  ");
		sb.append("MTBF = ");
		sb.append(this.MTBF);
		
		return sb.toString();

	}
	
	// ****************************************************************

	public int MTBF() {
	
		return this.MTBF;
		
	}

	// ****************************************************************

	private void checkProperties() throws GridException {

		if (this.MTBF < 0) {
			throw new GridException("checkProperties(): "+
									"illegal mean time between failures");
		}

	}

	// ****************************************************************

	private int MTBF;
	
}

