/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveTaskRunner.java

package lbg.resource.execution;

import lbg.common.exception.*;
import lbg.middleware.execution.*;
import lbg.protocol.api.GridApplication;
import lbg.protocol.data.*;
import lbg.task.Task;

/** A LiveTaskRunner is an extended class loader.
 * It loads the target Grid application (stored as a jar in the target Task)
 * into VM state space, then runs it.
 * <p>Related logger: lbg.resource
 * @author Xavier Dalem, Cyril Briquet
 */
class LiveTaskRunner extends ClassLoader {

	/** Constructs a new LiveTaskRunner.
	 */
	LiveTaskRunner(Task t,String supplier_id,String playpen_dir)
		throws GridException {

		if (t == null) {
			throw new GridException("LiveTaskRunner(): illegal task");
		}
		if (supplier_id == null) {
			throw new GridException("LiveTaskRunner(): illegal Supplier id");
		}
		if (playpen_dir == null) {
			throw new GridException("LiveTaskRunner(): illegal playpen dir");
		}
		
		this.t = t;
		this.supplier_id = supplier_id;
		this.playpen_dir = playpen_dir;
		this.gapp = new GridClassLoader().load(t);

		// Set input data and parameters
		this.gapp.setParameters(this.t.inputParameters());
		this.gapp.setInputData(this.t.getInputDataSet());
		this.gapp.setSupplier(this.supplier_id);
		this.gapp.setPlaypen(this.playpen_dir);
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[LiveTaskRunner]");

		return sb.toString();
		
	}
	
	// ****************************************************************

	/** Runs the target Task, then returns its output data file.
	 * <p>If appropriate, task data should have been stored before instanciating
	 * this object. That should have been done by the calling process.
	 */
	GridData go() throws GridException {
		
		this.gapp.compute();
		
		StringBuilder output_fn = new StringBuilder();
		output_fn.append(this.t.consumerID()).
			append(".job").
			append(this.t.jobID()).
			append(".task").
			append(this.t.id());
		
		return new InlineGridData(output_fn.toString(),this.gapp.getResult());

	}

	// ****************************************************************

	private final Task t;
	private final String supplier_id;
	private final String playpen_dir;
	private final GridApplication gapp;

}

