/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// ResourceServiceFactory.java

package lbg.resource.service;

import lbg.*;
import lbg.common.exception.*;
import lbg.resource.*;

/**
 * @author Cyril Briquet
 */
public abstract class ResourceServiceFactory {

	public static ResourceService createResourceService(Resource owner_resource)
		throws GridException {

		switch (LightweightBarteringGrid.getMode()) {
		case LIVE_MODE:
			if (owner_resource instanceof LiveResource == false) {
				throw new GridException("createResourceService(): "+
										"class mismatch");
			}
			return
				new LiveResourceService((LiveResource)owner_resource);
		case SIM_MODE:
			if (owner_resource instanceof SimulatedResource == false) {
				throw new GridException("createResourceService(): "+
										"class mismatch");
			}
			return
				new SimulatedResourceService((SimulatedResource)owner_resource);
		default:
			throw new GridException("createResourceService(): "+
									"unsupported mode");
		}
		
	}

}

