/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedResourceService.java

package lbg.resource.service;

import lbg.common.exception.*;
import lbg.protocol.data.*;
import lbg.resource.*;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public class SimulatedResourceService implements ResourceService {

	protected SimulatedResourceService(SimulatedResource owner_resource)
		throws GridException {
	
		if (owner_resource == null) {
			throw new GridException("SimulatedResourceService(): "+
									"illegal owner Resource");
		}
		
		this.owner_resource = owner_resource;
		
	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SimulatedResourceService ");
		sb.append(this.owner_resource.id());
		sb.append("]");

		return sb.toString();

	}
	
	public ResourceHandle createHandle() throws GridException {
		
		return new SimulatedResourceHandle(this.owner_resource.id(),this);
		
	}

	
	public String id() {
		
		return this.owner_resource.id();
		
	}
	
	public int cacheCapacity() {
		
		return this.owner_resource.cacheCapacity();
		
	}

	public boolean idle() {
	
		return this.owner_resource.idle();
		
	}

	public boolean isAlive() {
	
		return true;
		
	}

	/**
	 * @deprecated
	 */
	@Deprecated
	public Task runningTask() {
		
		return this.owner_resource.runningTask();
		
	}

	public boolean runTask(Task t,GridData[][] working_set)
		throws GridException {
		
		if (this.owner_resource.setWorkingSet(working_set) == false) {
			return false;
		}
		
		this.owner_resource.runTask(t);
		
		return true;

	}

	public boolean setWorkingSet(GridData[][] working_set)
		throws GridException {
		
		return this.owner_resource.setWorkingSet(working_set);

	}

	public void cancelTask() throws GridException {

		this.owner_resource.cancelTask();
		
	}
	
	public long expectedTaskRuntime() throws GridException {
		
		return this.owner_resource.expectedTaskRuntime();		
		
	}

	public long taskStartTime() {
		
		return this.owner_resource.taskStartTime();
		
	}

	// ****************************************************************

	private final Resource owner_resource;

}

