/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveSearchEngineClient.java

package lbg.searchengine;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.service.*;
import lbg.searchengine.service.*;

import java.util.Timer;

/**
 * @author Cyril Briquet
 */
public class LiveSearchEngineClient extends SearchEngineClient {
	
	/** Creates a new Search Engine client.
	 * @param reference search engine server
	 * @param owner_peer manager Peer (can be null, then set afterwards,
	 * see {@link #setOwnerPeer(ExternalPeerHandle)})
	 * @param timeout time to wait before updating database (in seconds)
	 * @throws GridException if the parameters are invalid
	 */
	public LiveSearchEngineClient(SearchEngineHandle reference,
						 		  ExternalPeerHandle owner_peer,
								  int timeout)
			throws GridException {
		
		super(reference,owner_peer,timeout);
	
		if (timeout <= 0) {
			throw new GridException("SearchEngineClient(): invalid timeout");
		}

		this.online = false;
		this.timeout = timeout;
		
	}
	
	public String toString() {
	
		return CommonStringHandling.
			replaceTag(super.toString(),"[SearchEngineClient",
									 	"[LiveSearchEngineClient");

	}
	
	// ****************************************************************

	public synchronized void startService() {

		if (this.online == true) {
			return;
		}
		else {
			this.online = true;
		}

		Timer t = new Timer("SearchEngineClient-daemon",true);
		long delay = ((long)this.timeout)*1000L;
		t.schedule(this,delay,delay);
		
	}

	// ****************************************************************

	private       boolean online;
	private final int timeout;
	
}

