/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveSearchEngineServer.java

package lbg.searchengine;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.peer.service.*;
import lbg.protocol.rpc.*;

import java.util.ArrayList;
import java.util.Timer;
import java.util.TimerTask;

/**
 * @author Cyril Briquet
 */
public class LiveSearchEngineServer extends SearchEngineServer {

	/** Creates a Search Engine server.
	 * @param id Search Engine id
	 * @param host Search Engine hostname
	 * @param port Search Engine port
	 * @param timeout timeout before handles are checked for activity
	 * (in seconds)
	 */
	public LiveSearchEngineServer(String id,String host,int port,int timeout)
		throws GridException {
		
		super(id,host,port,timeout);
		
		// ****************
		
		this.svc_thread = null;
		this.online = false;
		this.checker = null;

	}
	
	public String toString() {
	
		return CommonStringHandling.
			replaceTag(super.toString(),"[SearchEngineServer",
									 	"[LiveSearchEngineServer");

	}
	
	// ****************************************************************

	public synchronized void startService() throws GridException {

		if (this.online == true) {
			return;
		}
		else {
			this.online = true;
		}
		
		RemoteCallDaemon rc_daemon =
			new RemoteCallDaemon(RemoteCall.CallType.SEARCH,
								 this.port,this.service(),null);

		this.svc_thread =
			new Thread(rc_daemon,"Peer-to-SearchEngine-daemon");
		this.svc_thread.start();

		// ****************
		
		this.checker = new HandleChecker(handles_list);

		// ****************

		Timer t = new Timer("SearchEngineServer-daemon",true);
		long delay = ((long)this.timeout)*1000L;
		t.schedule(this.checker,delay,delay);

	}

	public synchronized boolean isAlive() {
		
		return (this.svc_thread != null) ? this.svc_thread.isAlive() : false;
		
	}

	// ****************************************************************

	private HandleChecker checker;
	private Thread svc_thread;
	private boolean online;

	// ****************************************************************

	private class HandleChecker extends TimerTask {
		
		HandleChecker(ArrayList<ExternalPeerHandle> list) throws GridException {
			
			if (list == null) {
				throw new GridException("HandleChecker(): "+
										"illegal handles list");
			}
			
			this.list = list;
			
		}
		
		public void run() {
			/* Unsynchronized access should speed up things but we have
			 * to check the bounds at each iteration as it may change, and
			 * when calling remove, we must return stay at the same element
			 * as the array is shifted (logically, the actual behaviour
			 * is likely implementation-specific).
			 */
			for (int i = 0 ; i < list.size() ; i++) {
				ExternalPeerHandle h = list.get(i);
				if (h.isAlive() == false) {
					remove(h);
					i--; // Stay in place, a new element was shifted here
				}
			}
		}

		private final ArrayList<ExternalPeerHandle> list;

	}

	// ****************************************************************

}

