/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SearchEngineResponse.java

package lbg.searchengine;

import lbg.common.exception.GridException;
import lbg.peer.service.ExternalPeerHandle;
import lbg.searchengine.service.SearchEngineHandle;

import java.io.Serializable;

/** A wrapper to include various information from a search engine.
 * @author Xavier Dalem
 * @since 2007-03-21
 */
public class SearchEngineResponse implements Serializable {
	private static final long serialVersionUID = 522603431626768614L;

	/** A list of probably valid peer handles. */
	public final ExternalPeerHandle[] handles;
	/** Server timestamp of this response, useful for
	 * {@link SearchEngineHandle#getHandles(long)}. */
	public final long timestamp;

	/** Creates a search engine response.
	 * 
	 * @param handles The handles the response consists of. Zero-sized for none.
	 * @throws GridException
	 */
	public SearchEngineResponse(ExternalPeerHandle[] handles)
			throws GridException {
		if (handles == null)
			throw new GridException("Cannot set response handles to null");
		
		this.handles = handles;
		timestamp = lbg.LightweightBarteringGrid.getTime();
	}
	
	public String toString() {
		StringBuilder sb = new StringBuilder("Response received at ")
			.append(timestamp).append(", containing :\n{ ");
		for (ExternalPeerHandle handle: handles)
			sb.append(handle.id()).append(" ");
		sb.append('}');
		return sb.toString();
	}
}
