/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveSearchEngineHandle.java

package lbg.searchengine.service;

import lbg.common.exception.GridException;
import lbg.peer.service.ExternalPeerHandle;
import lbg.protocol.rpc.RemoteCall;
import lbg.searchengine.SearchEngineResponse;

/**
 * @author Xavier Dalem
 */
public class LiveSearchEngineHandle implements SearchEngineHandle,
		java.io.Serializable {
	private static final long serialVersionUID = 2351399771722082923L;
	private final String id;
	private final String host;
	private final int port;
	
	public LiveSearchEngineHandle(String id, String host, int port)
			throws GridException {
		if (id == null || id.length() == 0 || host == null
				|| host.length() == 0 || port <= 0 )
			throw new GridException("Illegal parameters");
		
		this.id = id;
		this.host = host;
		this.port = port;
		
	}

	public void add(ExternalPeerHandle handle) throws GridException {
		if (handle == null)
			throw new GridException("null handle");
		
		try {
			RemoteCall rc = new RemoteCall(RemoteCall.CallType.SEARCH,
				"add", new Class[] {
					Class.forName("lbg.peer.service.ExternalPeerHandle")},
				new Object[] {handle} );
			rc.send(host, port, false);
		} catch (ClassNotFoundException e) {
			throw new GridException(
				"Critical: could not find one of the base classes", e);
		}
	}

	public SearchEngineResponse getHandles() throws GridException {
		Object ret = null;
		RemoteCall rc = new RemoteCall(RemoteCall.CallType.SEARCH,
			"getHandles", new Class[0], new Object[0]);
		ret = rc.send(host, port, true);
		
		if (ret == null || !(ret instanceof SearchEngineResponse))
			return null;
		
		return ((SearchEngineResponse) ret);
		
	}

	public SearchEngineResponse getHandles(long since) throws GridException {
		RemoteCall rc = new RemoteCall(RemoteCall.CallType.SEARCH,
			"getHandles", new Class[] {Long.TYPE}, new Object[] {since} );
		final Object ret = rc.send(host, port, true);
		
		if (ret == null || !(ret instanceof SearchEngineResponse))
			return null;
		
		return ((SearchEngineResponse) ret);
	}

	public String id() {
		return id;
	}

}
