/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveSearchEngineService.java

package lbg.searchengine.service;

import lbg.common.exception.GridException;
import lbg.peer.service.ExternalPeerHandle;
import lbg.searchengine.SearchEngineResponse;
import lbg.searchengine.SearchEngineServer;

/** Live service for the search engine
 * 
 * @author Xavier Dalem
 * @since 2007-03-21
 */
public class LiveSearchEngineService implements SearchEngineService {
	private final SearchEngineServer server;

	protected LiveSearchEngineService(SearchEngineServer server)
			throws GridException {
		if (server == null)
			throw new GridException("Invalid server");

		this.server = server;
	}

	public SearchEngineHandle createHandle() throws GridException {
		return new LiveSearchEngineHandle(server.id, server.hostname,
			server.port);
	}

	public void add(ExternalPeerHandle handle) throws GridException {
		server.add(handle);
	}

	public SearchEngineResponse getHandles() throws GridException {
		return server.getHandles();
	}

	public SearchEngineResponse getHandles(long since) throws GridException {
		return server.getHandles(since);
	}

	public String id() {
		return server.id;
	}

}
