/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SearchEngineHandle.java

package lbg.searchengine.service;

import lbg.common.exception.GridException;
import lbg.peer.service.ExternalPeerHandle;
import lbg.searchengine.SearchEngineResponse;

/** Handle to access a search engine's services.<br>
 * Available operations are list and add, but removal is prohibited for
 * security reasons.
 * @see SearchEngineResponse
 * @author Xavier Dalem
 * @since 2007-03-21
 */
public interface SearchEngineHandle {
	
	/** Returns this engine's ID. */
	public String id();

	/** Gets all handles that this engine currently knows.
	 * 
	 * @return A structured list of handles
	 * @throws GridException 
	 */
	public SearchEngineResponse getHandles() throws GridException;

	/** Gets handles newer than a specified time.
	 * 
	 * @param since Timestamp of the last response
	 * @return A structured list of handles
	 * @throws GridException 
	 */
	public SearchEngineResponse getHandles(long since) throws GridException;

	/** Adds a handle to this SearchEngine. The handle's state will be checked
	 * before addition.
	 * 
	 * @param handle The handle to add
	 * @throws GridException If the handle is invalid
	 */
	public void add(ExternalPeerHandle handle) throws GridException;

}
