/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedSearchEngineHandle.java

package lbg.searchengine.service;

import lbg.common.exception.GridException;
import lbg.peer.service.ExternalPeerHandle;
import lbg.searchengine.SearchEngineResponse;

/** Simulated handle to the search engine.
 * 
 * @author Xavier Dalem
 * @since 2007-03-21
 */
public class SimulatedSearchEngineHandle implements SearchEngineHandle {
	private final SimulatedSearchEngineService service;

	public SimulatedSearchEngineHandle(SimulatedSearchEngineService service)
			throws GridException {
		if (service == null)
			throw new GridException("Invalid service");
		
		this.service = service;
	}

	public void add(ExternalPeerHandle handle) throws GridException {
		service.add(handle);
	}

	public SearchEngineResponse getHandles() throws GridException {
		return service.getHandles();
	}

	public SearchEngineResponse getHandles(long since) throws GridException {
		return service.getHandles(since);
	}

	public String id() {
		return service.id();
	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SimulatedSearchEngineHandle] to service ");
		sb.append(id());
		
		return sb.toString();
		
	}
}

