/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimTask.java

package lbg.simulator;

import lbg.common.exception.GridException;
import lbg.protocol.api.GridApplication;
import lbg.protocol.data.GridData;
import java.io.IOException;
import java.util.Properties;

/** A SimTask is a wrapper class enabling the LBG Simulator
 * to be run as a GridApplication.
 * <p>Particularly useful to run a parameter sweep over multiple scenarios.
 * @author Xavier Dalem, Cyril Briquet
 */
public class SimTask implements GridApplication {

	public SimTask() {
	
		this.props = null;
	
	}
	
	/** {@inheritDoc}
	 * @param datas target simulation description file
	 */
	public void setInputData(GridData[] datas) throws GridException {
		
		if (datas.length != 1) {
			throw new GridException("setInputData(): only one .sdf allowed");
		}
		
		this.props = new Properties();
		try {
			this.props.load(datas[0].getInputStream());
		}
		catch (IOException e) {
			throw new GridException("setInputData(): couldn't load Properties "+
									"from given .sdf file", e);
		}
		
	}

	public void setParameters(Object[] parameters) throws GridException {}

	public void setSupplier(String supplier_id) throws GridException {}

	public void setPlaypen(String playpen_dir) throws GridException {}
	
	public void compute() {
		
		try {
			System.err.println("[Grid-Aware Simulator] up and running");
			Simulator sim = new Simulator(props);
			System.err.println("[Grid-Aware Simulator] Simulator loaded");
			sim.simulate();
			System.err.println("[Grid-Aware Simulator] simulation completed");
		}
		catch (GridException e) {
			e.printStackTrace(System.err);
		}
		
	}

	public byte[] getResult() {
		
		String msg = "Simulation sucessful, results available in the log file";
		return msg.getBytes();
		
	}

	private Properties props;

}

