/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// Event.java

package lbg.simulator.event;

import lbg.common.exception.*;
import lbg.common.io.*;

/**
 * @author Cyril Briquet
 */
public abstract class Event implements Comparable<Event> {

	Event(long id,long timestamp) throws GridException {

		if (id < 0) {
			throw new GridException("Event(): illegal id");
		}

		if (timestamp < 0) {
			throw new GridException("Event(): illegal timestamp");
		}
		
		this.id = id;
		this.id_as_key = Long.valueOf(this.id);
		this.timestamp = timestamp;
	
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		sb.append("[Event ");
		try {
			sb.append(CommonStringHandling.fillWithHeadingSpaces(this.id,4));
		}
		catch (GridException e) {
			sb.append(this.id);
		}
		sb.append("] t=");
		sb.append(this.timestamp);

		return sb.toString();
		
	}
	
	public int compareTo(Event other) {
	
		long diff = this.id - other.id();
		if (diff < 0) {
			return -1;
		}
		else if (diff > 0) {
			return +1;
		}
		else /* if (diff == 0) */ {
			return 0;
		}
		
	}
	
	public long id () {
		
		return this.id;
		
	}
	
	public Long idAsKey() {
		
		return this.id_as_key;
		
	}

	public long timestamp() {
		
		return this.timestamp;
		
	}
	
	private final long id;
	private final Long id_as_key;
	private final long timestamp;
	
}

