/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// EventContainer.java

package lbg.simulator.event;

import lbg.common.exception.*;

/** An EventContainer is a helper class used only as EventList.firstEvent()
 * return type.
 * @author Cyril Briquet
 */
public class EventContainer {

	public EventContainer(Event evt,boolean is_last_event_at_current_timestamp)
		throws GridException {
	
		if (evt == null) {
			throw new GridException("EventContainer(): illegal Event");
		}
		
		this.evt = evt;
		this.is_last_event_at_current_timestamp =
			is_last_event_at_current_timestamp;

	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		sb.append("[EventContainer]");
		if (is_last_event_at_current_timestamp) {
			sb.append(" (last event at current timestamp)");
		}
		sb.append("\n  ->  ");
		sb.append(this.evt);

		return sb.toString();
		
	}

	public Event event() {
		
		return this.evt;
		
	}
	
	public boolean isLastEventAtCurrentTimestamp() {
		
		return this.is_last_event_at_current_timestamp;
		
	}
	
	private final Event evt;
	private final boolean is_last_event_at_current_timestamp;
	
}

