/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SubmittedJobEvent.java

package lbg.simulator.event;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.user.*;

/**
 * @author Cyril Briquet
 */
public class SubmittedJobEvent extends Event {

	public SubmittedJobEvent(long id,long timestamp,UserAgent user,
							 String owner_id)
		throws GridException {

		super(id,timestamp);
		
		if (user == null) {
			throw new GridException("SubmittedJobEvent(): illegal User Agent");
		}

		if (owner_id == null) {
			throw new GridException("SubmittedJobEvent(): illegal owner Peer");
		}
		
		this.user = user;
		this.owner_id = owner_id;
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[Event","[SubmittedJobEvent "));
		
		sb.append(", owner=");
		sb.append(this.owner_id);

		return sb.toString();
		
	}
	
	public UserAgent user() {
	
		return this.user;
		
	}

	public String ownerID() {
	
		return this.owner_id;
		
	}
	
	private UserAgent user;
	private String owner_id;

}

