/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// TaskEvent.java

package lbg.simulator.event;

import lbg.common.exception.*;
import lbg.common.io.*;
import lbg.resource.*;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public abstract class TaskEvent extends Event {

	TaskEvent(long id,long timestamp,
			  String consumer_id,String supplier_id,Task t,Resource res)
		throws GridException {

		super(id,timestamp);
		
		if (consumer_id == null) {
			throw new GridException("TaskEvent(): illegal consumer Peer id");
		}
		if (supplier_id == null) {
			throw new GridException("TaskEvent(): illegal supplier Peer id");
		}
		if (t == null) {
			throw new GridException("TaskEvent(): illegal Task");
		}
		if (res == null) {
			throw new GridException("TaskEvent(): illegal Resource");
		}
		
		this.consumer_id = consumer_id;
		this.supplier_id = supplier_id;
		this.t = t;
		this.res = res;
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();

		sb.append(CommonStringHandling.
					replaceTag(super.toString(),
							   "[Event","[TaskEvent"));

		sb.append(", consumer=");
		sb.append(this.consumer_id);
		sb.append(", supplier=");
		sb.append(this.supplier_id);

		return sb.toString();
		
	}
	
	// ****************************************************************

	public String consumerID() {
	
		return this.consumer_id;
		
	}
	
	public String supplierID() {
	
		return this.supplier_id;
		
	}

	public Task task() {
		
		return this.t;
		
	}
	
	public Resource runner() {
		
		return this.res;
		
	}
	
	// ****************************************************************

	private final String consumer_id;
	private final String supplier_id;
	private final Task t;
	private final Resource res;

}

