/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// JDFWriterFactory.java

package lbg.simulator.tools.jdf;

import lbg.common.exception.*;
import java.util.Iterator;

/**
 * @author Cyril Briquet
 */
public class JDFWriterFactory {

	/** Constructs a new JDF file writer factory.
	 * @param m target middleware (LBG, OurGrid)
	 * @param upload_jar_dep flag to turn on/off the upload of
	 * all LBG jar dependencies (ignored and considered true by default
	 * if target middleware is OurGrid)
	 * @exception GridException if a parameter is illegal
	 */
	public JDFWriterFactory(Middleware m,boolean upload_jar_dep)
		throws GridException {
	
		if (m == null) {
			throw new GridException("JDFWriterFactory(): "+
									"illegal middleware");
		}
		this.m = m;
		this.upload_jar_dep = upload_jar_dep;
		
	}
	
	public String toString() {
	
		StringBuilder sb = new StringBuilder();
		sb.append("[JDFWriterFactory] Middleware=");
		sb.append(this.m);

		return sb.toString();

	}

	// ****************************************************************

	public JDFWriter
		createJDFWriter(String job_label,
						String scenario_complete_filename,
						String jar_complete_filename,
						Iterator<String> scenarii,
						String main_class)
		throws GridException {
		
		switch (m) {
		case LBGRID:
			return new LBGridJDFWriter(
				job_label,scenario_complete_filename,
				jar_complete_filename,scenarii,main_class,this.upload_jar_dep);
		case OURGRID:
			return new OurGridJDFWriter(
				job_label,scenario_complete_filename,
				jar_complete_filename,scenarii,main_class,true);
		default:
			throw new GridException("createJDFWriter(): "+
									"unsupported middleware");
		}
		
	}
	
	// ****************************************************************

	private final Middleware m;
	private final boolean upload_jar_dep;

}

