/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LBGridTaskDescription.java

package lbg.simulator.tools.jdf;

import lbg.common.exception.*;

/**
 * @author Cyril Briquet
 */
public class LBGridTaskDescription implements TaskDescription {

	protected LBGridTaskDescription(String[] inputs,String[] parameters,
						   		 	String jar,String main_class,
									String remote_cmd,String[] outputs)
		throws GridException {
		
		setInputs(inputs);
		setParameters(parameters);
		setJar(jar);
		setMainClass(main_class);
		setRemoteCmd(remote_cmd);
		setOutputs(outputs);
		
	}
	
	public LBGridTaskDescription() throws GridException {
		
		this.inputs = null;
		this.parameters = null;
		this.main_class = null;
		this.jar = null;
		/*this.remote_cmd = null;*/
		/*this.outputs = null;*/
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[LBGridTaskDescription]");
		
		return sb.toString();
		
	}
	
	// ****************************************************************

	public synchronized void setInputs(String[] inputs) throws GridException {
	
		if (inputs == null) {
			throw new GridException("setInputs(): "+
									"illegal inputs array");
		}
		for (String s : inputs) {
			if (s.length() < 1) {
				throw new GridException("setInputs(): "+
										"illegal input data file");
			}
		}

		this.inputs = inputs.clone();

	}
	
	public synchronized void setParameters(String[] parameters)
		throws GridException {
	
		if (parameters == null) {
			throw new GridException("setParameters(): "+
									"illegal parameters array");
		}
		for (String s : parameters) {
			if (s.length() < 1) {
				throw new GridException("setParameters(): "+
										"illegal parameter");
			}
		}

		this.parameters = parameters.clone();

	}
	
	public synchronized void setJar(String jar) throws GridException {
		
		if (jar == null) {
			throw new GridException("setJar(): illegal jar");
		}

		this.jar = jar;

	}

	public synchronized void setMainClass(String main_class)
		throws GridException {
		
		if (main_class == null) {
			throw new GridException("setMainClass(): illegal main class");
		}

		this.main_class = main_class;

	}

	public synchronized void setRemoteCmd(String remote_cmd)
		throws GridException {
		
		if (remote_cmd == null) {
			throw new GridException("setRemoteCmd(): "+
									"illegal remote command");
		}

		/*this.remote_cmd = remote_cmd; -- ignored*/

	}
	
	public synchronized void setOutputs(String[] outputs) throws GridException {
	
		if (outputs == null) {
			throw new GridException("setOutputs(): "+
									"illegal outputs array");
		}
		for (String s : outputs) {
			if (s.length() < 1) {
				throw new GridException("setOutputs(): "+
										"illegal outputs array");
			}
		}
		
		/*this.outputs = outputs; -- not needed,
		as LBG Task output consists of 1 ouput file with conventional name*/

	}

	// ****************************************************************

	public synchronized String format(String task_name) throws GridException {
	

		if ((task_name == null) ||
			(task_name.length() < 1)) {
			throw new GridException("getLBGridFormatting(): "+
									"illegal Task name");
		}
		
		StringBuilder sb = new StringBuilder();

	
		sb.append(task_name).append(".jar");
		if (this.jar != null) {
			sb.append(" = ").append(this.jar);
		}
		sb.append("\n");
		
		sb.append(task_name).append(".main_class");
		if (this.main_class != null) {
			sb.append(" = ").append(this.main_class);
		}
		sb.append("\n");
		
		sb.append(task_name).append(".parameters");
		if (this.parameters != null) {
			sb.append(" = ");
			int i = 0;
			for (String parameter : this.parameters) {
				sb.append(parameter);
				if (++i < this.parameters.length) sb.append(", ");
			}
		}
		sb.append("\n");
		
		sb.append(task_name).append(".datas");
		if (this.inputs != null) {
			sb.append(" = ");
			int i = 0;
			for (String input : this.inputs) {
				sb.append(input);
				if (++i < this.inputs.length) sb.append(", ");
			}
		}
		sb.append("\n");

		return sb.toString();
		
	}
	
	// ****************************************************************

	private String[] inputs;
	private String[] parameters;
	private String jar;
	private String main_class;
	/*private String remote_cmd;*/
	/*private String[] outputs;*/

}

