/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LogChartRequest.java

package lbg.simulator.tools.panorama;

import lbg.common.exception.*;

import java.awt.image.BufferedImage;

/**
 * @author Cyril Briquet
 */
public class LogChartRequest {

	public LogChartRequest(LogChartDrawingListener listener,int chart_id,
						   String... col_titles) throws GridException {
	
		if (listener == null) {
			throw new GridException("LogChartRequest(): illegal listener");
		}
		if (chart_id < 0) {
			throw new GridException("LogChartRequest(): illegal chart id");
		}
		if ((col_titles == null) || (col_titles.length < 1)) {
			throw new GridException("LogChartRequest(): "+
									"no column titles given");
		}
		
		this.listener   = listener;
		this.chart_id   = chart_id;
		this.col_titles = col_titles;
		this.chart_img  = null;
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[LogChartRequest]");
		
		return sb.toString();
		
	}

	// ****************************************************************

	public synchronized String[] getColumnTitles() {
		
		return this.col_titles.clone();
		
	}
	
	public synchronized void setChartImage(BufferedImage chart_img)
		throws GridException {
		
		if (chart_img == null) {
			throw new GridException("setChartImage(): illegal chart image");
		}
		
		this.chart_img = chart_img;
		
	}

	public synchronized BufferedImage getChartImage() {
		
		return this.chart_img;
		
	}

	// ****************************************************************

	public  final LogChartDrawingListener listener;
	public  final int chart_id;
	private final String[] col_titles;
	private       BufferedImage chart_img;
	
}

