/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LocalTaskComparator.java

package lbg.task;

/** Specialized Comparator targeting pairwise comparison
 * of Local/Consumption Tasks id.
 * @author Cyril Briquet
 */
public class LocalTaskComparator extends TaskComparator {

	// Sort by Job, BoT and Task id (in Local id space)
	public int compare(Task t1,Task t2) {
		
		int job_id_1 = t1.jobID();
		int job_id_2 = t2.jobID();
		
		if (job_id_1 < job_id_2) {
			return -1;
		}
		else if (job_id_1 > job_id_2) {
			return +1;
		}
		else /* if (job_id_1 == job_id_2) */ {
			int bot_id_1 = t1.botID();
			int bot_id_2 = t2.botID();
			
			if (bot_id_1 < bot_id_2) {
				return -1;
			}
			else if (bot_id_1 > bot_id_2) {
				return +1;
			}
			else /* if (bot_id_1 == bot_id_2) */ {
				int task_id_1 = t1.id();
				int task_id_2 = t2.id();
				
				if (task_id_1 < task_id_2) {
					return -1;
				}
				else if (task_id_1 > task_id_2) {
					return +1;
				}
				else /* if (task_id_1 == task_id_2) */ {
					return 0;
				}
			}
		}
	}

	// ****************************************************************

	public static LocalTaskComparator getDefaultComparator() {
	
		return LocalTaskComparator.DEFAULT_COMPARATOR;
		
	}
	
	// ****************************************************************

	private static final LocalTaskComparator DEFAULT_COMPARATOR =
		new LocalTaskComparator();

}


