/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// UserAgent.java

package lbg.user;

import lbg.common.exception.*;
import lbg.peer.service.*;
import lbg.peer.workflow.*;
import lbg.task.*;
import lbg.user.service.*;

/**
 * @author Cyril Briquet
 */
public abstract class UserAgent {

	UserAgent(String id,UserPeerHandle peer)
		throws GridException {
	
		if (id == null) {
			throw new GridException("UserAgent(): illegal id");
		}
		if (peer == null) {
			throw new GridException("UserAgent(): illegal Peer");
		}
		
		this.id = id;
		this.peer = peer;
		
	}
	
	public synchronized String toString() {
	
		StringBuilder sb = new StringBuilder();
		
		sb.append("[UserAgent ");
		sb.append(this.id);
		sb.append("] using Peer ");
		sb.append(this.peer.id());

		return sb.toString();
		
	}
	
	// ****************************************************************

	public String id() {
		
		return this.id;
		
	}
	
	public UserPeerHandle usedPeer() {
		
		return this.peer;
		
	}
	
	public abstract UserService service();

	public abstract void notifyCompletedTask(Task t) throws GridException;
	
	public abstract void notifyCompletedJob(Task t) throws GridException;
	
	public abstract int submitJob(JobDescriptor jd) throws GridException;
	
	public abstract long submittedJobs();

	public abstract long completedJobs();

	public abstract boolean hasRunningJobs();

	// ****************************************************************

	private final String id;
	private final UserPeerHandle peer;
	
}

