/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// UAJobSubmission.java

package lbg.user.server;

import java.io.BufferedReader;
import java.io.IOException;

/** An UAJobSubmission represents a job submission request made to
 * the LiveUserAgentServer.
 * <p>The only parameter associated to this request is the path to
 * a properties file describing the Job to submit.
 * @author Gerard Dethier
 */
public class UAJobSubmission implements UAServerRequest {
	
	private String propFile;

	/** Constructor.
	 */
	public UAJobSubmission() {
		
	}

	/** Reads the path to the properties file describing the Job sent
	 * to the LiveUserAgentServer.
	 * @throws IOException If the path could not be read.
	 */
	public void readRequest(BufferedReader reader) throws IOException {
		if (reader == null) {
			throw new IllegalArgumentException("readRequest(): illegal reader");
		}
		propFile = reader.readLine();
	}

	/**
	 * Returns the path to the properties file describing the submitted Job.
	 * @return The path to a properties file.
	 */
	public String getPropertiesFile() {
		return propFile;
	}

}

