/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// UAServerRequestFactory.java

package lbg.user.server;

/** A UAServerRequestFactory instantiates the appropriate
 * UAServerRequest implementation given a request header.
 * 
 * <p>Currently supported headers:
 * <ul><li>"JobSubmission" is the header of a job submission request.</li>
 * <li>"ShutdownUser" is the header of a user shutdown request.</li>
 * </ul>
 * @author Gerard Dethier
 */
public class UAServerRequestFactory {

	/** Given a header, an instance of a Request implementation is returned.
	 * @param header The header of the request.
	 * @return An instance of a Request implementation,
	 * or null if no implementation is available.
	 */
	public static UAServerRequest getRequestObject(String header) {
		if("JobSubmission".equals(header)) {
			return new UAJobSubmission();
		} else if("ShutdownUser".equals(header)) {
			return new UAShutdown();
		}
		return null;
	}

}

