/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// LiveUserService.java

package lbg.user.service;

import lbg.common.exception.*;
import lbg.task.*;
import lbg.user.*;

/**Live implementation of the User service
 * @author Xavier Dalem, Cyril Briquet
 */
public class LiveUserService implements UserService {

	private final LiveUserAgent owner_user;
	private final UserHandle self_user_handle;

	/** Creates a User service
	 * @param owner_user User concerned by this service
	 */
	protected LiveUserService(UserAgent owner_user)
		throws GridException {
		if (owner_user == null) {
			throw new GridException("LiveUserService(): "+
									"illegal owner user");
		}
		if (! (owner_user instanceof LiveUserAgent)) {
			throw new GridException("LiveUserService(): user is not a Live "
				+ "and lacks approriate methods");
		}
		
		this.owner_user = (LiveUserAgent)owner_user;
		
		this.self_user_handle =
			new LiveUserHandle(this.owner_user.id(),
							   this.owner_user.host(),this.owner_user.port());
	}

	/** String representation of the service */
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[LiveUserService ");
		sb.append(owner_user.id());
		sb.append("]");
		
		return sb.toString();
		
	}

	/** Creates a handle to parent user */
	public UserHandle createHandle() throws GridException {

		return this.self_user_handle;

	}

	/** Get user id */
	public String id() {
		return this.owner_user.id();
	}

	/** Notify a user of a completed task
	 * @param t The completed task */
	public void notifyCompletedTask(Task t) throws GridException {
		this.owner_user.notifyCompletedTask(t);
	}
	
	/** Notify a user of a completed job
	 * @param t Last task from the completed job
	 * @throws GridException if no such job was sent in this session */
	public void notifyCompletedJob(Task t) throws GridException {
		this.owner_user.notifyCompletedJob(t);
	}
	
}

