/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedUserHandle.java

package lbg.user.service;

import lbg.common.exception.*;
import lbg.task.*;

/**
 * @author Cyril Briquet
 */
public class SimulatedUserHandle implements UserHandle {

	public SimulatedUserHandle(String id,
							   SimulatedUserService user_service)
		throws GridException {
	
		if (id == null) {
			throw new GridException("SimulatedUserHandle(): illegal id");
		}
		
		if (user_service == null) {
			throw new GridException("SimulatedUserHandle(): "+
									"illegal ResourceService");
		}

		this.id = id;
		this.user_service = user_service;
		
	}
	
	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SimulatedUserHandle ");
		sb.append(this.id);
		sb.append("]\n\t    ");
		sb.append(this.user_service);
		
		return sb.toString();
		
	}
	
	
	public String id() {
		
		return this.user_service.id();
		
	}

	public void notifyCompletedTask(Task t) throws GridException {
		
		this.user_service.notifyCompletedTask(t);
		
	}
	
	public void notifyCompletedJob(Task t) throws GridException {
		
		this.user_service.notifyCompletedJob(t);
		
	}

	private String id;
	private SimulatedUserService user_service;

}

