/*
 *  Copyright (c) 2005-2008, Cyril Briquet, parts Xavier Dalem
 *
 *  This file is part of Lightweight Bartering Grid.
 *  Lightweight Bartering Grid is free software;
 *  you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Lightweight Bartering Grid is distributed in the hope that it will be
 *  useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Lightweight Bartering Grid; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

// SimulatedUserService.java

package lbg.user.service;

import lbg.common.exception.*;
import lbg.task.*;
import lbg.user.*;

/**
 * @author Cyril Briquet
 */
public class SimulatedUserService implements UserService {

	protected SimulatedUserService(UserAgent owner_user)
		throws GridException {
			
		if (owner_user == null) {
			throw new GridException("SimulatedUserService(): "+
									"illegal owner User");
		}
		
		this.owner_user = owner_user;

	}

	public String toString() {
		
		StringBuilder sb = new StringBuilder();
		
		sb.append("[SimulatedUserService ");
		sb.append(this.owner_user.id());
		sb.append("]");
		
		return sb.toString();
		
	}

	public UserHandle createHandle() throws GridException {
		
		return new SimulatedUserHandle(this.owner_user.id(),this);
		
	}

	public String id() {
		
		return this.owner_user.id();
		
	}

	public void notifyCompletedTask(Task t) throws GridException {
		
		this.owner_user.notifyCompletedTask(t);
		
	}
	
	public void notifyCompletedJob(Task t) throws GridException {
		
		this.owner_user.notifyCompletedJob(t);
		
	}

	private UserAgent owner_user;

}

